%% Generate an AFM-diagram to discriminate between tholeiitic and calc-
% alkaline magmatic series after Irvine & Baragar (1971).
%
% Reference: Irvine, T.N., Baragar, W.R.A., 1971. A Guide to the Chemical 
% Classification of the Common Volcanic Rocks. Canadian Journal of 
% Earth Sciences 8, 523-548.
%
% Link: doi:10.1139/e71-055

%% Run normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

%% Calculation
    a1sum = n1Na2O+n1K2O+(0.8998.*n1Fe2O3)+n1MgO;
    a1F   = ((0.8998.*n1Fe2O3)./a1sum)*sin(deg2rad(60));
    a1M   = (n1MgO./a1sum)+a1F*cot(deg2rad(60));
    
%% Create plot
AFM = figure('Visible','on','Position',[200,100,800,800]);
    movegui(AFM,'center')
    set(AFM,'Name','AFM diagram - FGAPP v1.0 - 1 dataset')
% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot tholeiitic/calc-alkaline boundary
    plot([0.693 0.660 0.632 0.598 0.570 0.536 0.500 0.464 0.428 0.375 0.186],...
        [0.349 0.381 0.406 0.435 0.454 0.472 0.481 0.472 0.453 0.412 0.260],...
        'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.5,0.6,'tholeiitic','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.5,0.35,'calc-alkaline','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    title('AFM diagram (after Irvine & Baragar, 1971)','FontSize',12,'FontWeight','b')
% Plot data
plot(a1M,a1F,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(1,-0.0425,'M (MgO)','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.05,-0.05,'A (Na_2O+K_2O)','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'F (FeO_t_o_t)','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear AFM
clear a1sum a1F a1M