%% Generate geotectonic discrimanation diagram after Cabanis & Lecolle (1989).
%
% Cabanis, B., Lecolle, M., 1989. The La/10-Y/15-Nb/8 diagram: a tool for 
% discriminating volcanic series and evidencing continental crust magmatic 
% mixtures and/or contamination [La diagramme La/10-Y/15-Nb/8: un outil 
% pour la discrimination des series volcaniques et la mise en evidence des 
% processus de melange et/ou de contamination crustale]. Comptes Rendus - 
% Academie des Sciences, Serie II 309, 2023-2029.

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)

%% Create data
    a1sum = (n1Y./15)+(n1Nb./8)+(n1La./10);
    a1Y   = ((n1Y./15)./a1sum)*sin(deg2rad(60));
    a1Nb   = ((n1Nb./8)./a1sum)+a1Y*cot(deg2rad(60));
    a2sum = (n2Y./15)+(n2Nb./8)+(n2La./10);
    a2Y   = ((n2Y./15)./a2sum)*sin(deg2rad(60));
    a2Nb   = ((n2Nb./8)./a2sum)+a2Y*cot(deg2rad(60));
    a3sum = (n3Y./15)+(n3Nb./8)+(n3La./10);
    a3Y   = ((n3Y./15)./a3sum)*sin(deg2rad(60));
    a3Nb   = ((n3Nb./8)./a3sum)+a3Y*cot(deg2rad(60));
    a4sum = (n4Y./15)+(n4Nb./8)+(n4La./10);
    a4Y   = ((n4Y./15)./a4sum)*sin(deg2rad(60));
    a4Nb   = ((n4Nb./8)./a4sum)+a4Y*cot(deg2rad(60));

%% Create plot
Cab1 = figure('Visible','on','Position',[200,100,800,800]);
    movegui(Cab1,'center')
    set(Cab1,'Name','Cabanis & Lecolle (1989) - FGAPP v1.0 - 4 datasets')
% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot tholeiitic/calc-alkaline boundary
    plot([0.500 0.380],[0.866 0.000],...
         [0.620 0.4735],[0.000 0.672],...
         [0.790 0.566],[0.364 0.256],...
         [0.620 0.491],[0.658 0.592],...
         [0.700 0.525],[0.520 0.437],...
         [0.507 0.4482],[0.520 0.494],...
         [0.343 0.4565],[0.593 0.543],...
         [0.436 0.286],[0.407 0.494],...
        'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.53,0.7,'3D','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.58,0.55,'3C','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.63,0.4,'3B','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.68,0.25,'3A','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.48,0.53,'2B','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.49,0.3,'2A','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.43,0.65,'1C','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.39,0.5,'1B','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.3,0.25,'1A','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
% Key
    text(0.68,0.78,...
    sprintf('1A - calc-alkali basalts\n1B - intermediate\n1C - volcanic-arc tholeiites\n2A - continental basalts\n2B - back-arc basin basalts\n3A - alkali basalts (intercontinental rifts)\n3B - E-type MORB (weakly enriched)\n3C - E-type MORB\n3D - N-type MORB'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
% Plot data
plot(a4Nb,a4Y,'Marker','^','MarkerFaceColor','y','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a3Nb,a3Y,'Marker','v','MarkerFaceColor','g','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a2Nb,a2Y,'Marker','o','MarkerFaceColor','b','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a1Nb,a1Y,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(1,-0.05,'Nb/8','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0,-0.05,'La/10','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'Y/15','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
title('La/Y/Nb diagram (after Cabanis & Lecolle, 1989)','Fontweight','b','FontSize',12)
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear Cab1
clear a1sum a1Y a1Nb
clear a2sum a2Y a2Nb
clear a3sum a3Y a3Nb
clear a4sum a4Y a4Nb