%% Creates two diagrams with incompatible element ratios (Zr/Nb vs. Nb/Th and
% Nb/Y vs. Zr/Y. Fields are redrawn after Condie (2005). Dotted division
% line is from Fitton et al. (1997).
% 
% Reference: Condie, K.C., 2005. High field strength element ratios in 
% Archean basalts: a window to evolving sources of mantle plumes? Lithos 79,
% 491-504.
%
% Link: http://dx.doi.org/10.1016/j.lithos.2004.09.014
%
%
% Reference: Fitton, J.G., Saunders, A.D., Norry, M.J., Hardarson, B.S., 
% Taylor, R.N., 1997. Thermal and chemical structure of the Iceland plume. 
% Earth and Planetary Science Letters 153, 197-208.
%
% Link: http://dx.doi.org/10.1016/S0012-821X(97)00170-2

% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)

% Calculate the ratios
    n1ZrdivNb = n1Zr./n1Nb;
    n1NbdivTh = n1Nb./n1Th;
    n1NbdivY  = n1Nb./n1Y;
    n1ZrdivY  = n1Zr./n1Y;
    
    n2ZrdivNb = n2Zr./n2Nb;
    n2NbdivTh = n2Nb./n2Th;
    n2NbdivY  = n2Nb./n2Y;
    n2ZrdivY  = n2Zr./n2Y;
    
    n3ZrdivNb = n3Zr./n3Nb;
    n3NbdivTh = n3Nb./n3Th;
    n3NbdivY  = n3Nb./n3Y;
    n3ZrdivY  = n3Zr./n3Y;
    
    n4ZrdivNb = n4Zr./n4Nb;
    n4NbdivTh = n4Nb./n4Th;
    n4NbdivY  = n4Nb./n4Y;
    n4ZrdivY  = n4Zr./n4Y;
    
    %% Zr/Nb vs. Nb/Th Diagram
    
co14 = figure('Visible','on','Position',[50,50,1000,700]);
      set(co14,'Name','Condie-Plots - Zr/Nb vs. Nb/Th - FGAPP v1.0 - 4 datasets')
semilogy([4.75 8 13.1 19.9 19.7 9.2 5.75 4.75],...
         [8.35 10.45 8.35 4.95 4.25 4.2 5 8.35],'k-',...
         [3.15 0.9 0.55 0.9 4.3 7.7 7.35 3.15],...
         [11 18 34 88 75 18.3 12.3 11],'k-',...
         [2.2 2.05 14.8 28.2 28.2 20.1 13 5.25 2.2],...
         [15 25.8 25.8 18.9 13.5 7.2 8 10.8 15],'k-',...
         [11.7 13.65 18.8 25.65 26.5 19.6 13.5 11.7],...
         [38 61 69 50 34.5 17.2 21.75 38],'k-','LineWidth',2)
        text(2.5,45,'ARC','fontsize',12,'fontweight','b')
        text(10,6,'OIB','fontsize',12,'fontweight','b')
        text(17,38,'N-MORB','fontsize',12,'fontweight','b')
        text(10,14,'Oceanic Plateau Basalts','fontsize',12,'fontweight','b')
      hold all
semilogy(n4NbdivTh,n4ZrdivNb,'^','MarkerEdgeColor','k',...
                                  'MarkerFaceColor','y',...
                                  'MarkerSize',6)
semilogy(n3NbdivTh,n3ZrdivNb,'v','MarkerEdgeColor','k',...
                                  'MarkerFaceColor','g',...
                                  'MarkerSize',6)
semilogy(n2NbdivTh,n2ZrdivNb,'o','MarkerEdgeColor','k',...
                                  'MarkerFaceColor','b',...
                                  'MarkerSize',6)
semilogy(n1NbdivTh,n1ZrdivNb,'s','MarkerEdgeColor','k',...
                                  'MarkerFaceColor','r',...
                                  'MarkerSize',6)
      hold off
        axis ([0 30 2 100])
        set(gca,'XTick',0:5:30,'YTick',[1 10 100],'YTickLabel',[10 100],'FontWeight','b','LineWidth',2)
        title('Zr/Nb vs. Nb/Th (after Condie, 2005)','fontsize',12,'fontweight','b')
        xlabel('Nb/Th','fontsize',12,'fontweight','b')
        ylabel('Zr/Nb','fontsize',12,'fontweight','b')                

        %% Nb/Y vs. Zr/Y Diagram
        
co24 = figure('Visible','on','Position',[75,75,1000,700]);
      set(co24,'Name','Condie-Plots - Nb/Y vs. Zr/Y - FGAPP v1.0 - 4 datasets')
loglog([1.17 1.25 4.1 6.45 5.65 1.325 1.17],...
       [0.067 0.13 0.95 0.82 0.315 0.04 0.067],'k-',...
       [4.59 4.47 10.2 13.3 14.8 13.65 8.6 6 4.59],...
       [0.82 1.63 5.5 5.6 3.2 2 1 0.7 0.82],'k-',...
       [2.1 1.7 1.8 4 4.1 3.15 2.6 2.1],...
       [0.0145 0.031 0.052 0.22 0.12 0.025 0.0165 0.0145],'k-',...
       [3.48 3.45 9.75 11 12.8 12.66 9.25 5.9 3.48],...
       [0.08 0.175 1 1.6 1.55 0.75 0.16 0.065 0.08],'k-',...
       [1 20],[0.0185 5.3],'k--',...
       'LineWidth',2)
      text(1.1,6,'PLUME SOURCES','fontsize',14,'fontweight','b')
      text(8,0.02,'NON-PLUME SOURCES','fontsize',14,'fontweight','b')
      text(6,0.18,'ARC','fontsize',12,'fontweight','b')
      text(7.6,2,'OIB','fontsize',12,'fontweight','b')
      text(2.05,0.035,'N-MORB','fontsize',12,'fontweight','b')
      text(2.07,0.2,sprintf('Oceanic Plateau\n    Basalts'),'fontsize',12,'fontweight','b')
    hold all
loglog(n4ZrdivY,n4NbdivY,'^','MarkerEdgeColor','k',...
                              'MarkerFaceColor','y',...
                              'MarkerSize',6)
loglog(n3ZrdivY,n3NbdivY,'v','MarkerEdgeColor','k',...
                              'MarkerFaceColor','g',...
                              'MarkerSize',6)
loglog(n2ZrdivY,n2NbdivY,'o','MarkerEdgeColor','k',...
                              'MarkerFaceColor','b',...
                              'MarkerSize',6)
loglog(n1ZrdivY,n1NbdivY,'s','MarkerEdgeColor','k',...
                              'MarkerFaceColor','r',...
                              'MarkerSize',6)
    hold off
    axis ([1 20 0.01 10])
    set(gca,'XTickLabel',[1 10],'YTickLabel',[0.01 0.1 1 10],'FontWeight','b','LineWidth',2)
    title('Nb/Y vs. Zr/Y (after Fitton et al., 1997, Condie, 2005)','fontsize',12,'fontweight','b')
    xlabel('Zr/Y','fontsize',12,'fontweight','b')
    ylabel('Nb/Y','fontsize',12,'fontweight','b')
    
    %% Clear data
clear co14 co24
clear n1ZrdivNb n1NbdivTh n1NbdivY n1ZrdivY
clear n2ZrdivNb n2NbdivTh n2NbdivY n2ZrdivY
clear n3ZrdivNb n3NbdivTh n3NbdivY n3ZrdivY
clear n4ZrdivNb n4NbdivTh n4NbdivY n4ZrdivY