%% Generates a geotectonic discrimination plot (Zr/4-2Nb-Y) after Meschede (1986).
%
% Meschede, M., 1986. A method of discriminating between different types of 
% mid-ocean ridge basalts and continental tholeiites with the NbZrY diagram.
% Chemical Geology 56, 207-218.
%
% Link: http://dx.doi.org/10.1016/0009-2541(86)90004-5

%% Runs normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

% Calculations
a1sum = (n1Zr./4)+(n1Nb.*2)+n1Y;
a1Nb  = ((n1Nb.*2)./a1sum)*sin(deg2rad(60));
a1Y   = (n1Y./a1sum)+a1Nb*cot(deg2rad(60));

%% Create a plot
meschede1 = figure('Visible','on','Position',[200,100,800,800]);
    movegui(meschede1,'center')
    set(meschede1,'Name','Meschede (1986) - FGAPP v1.0 - 1 dataset')

%% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','w','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
% Plot ticks
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot fields
    plot([0.5000 0.4550 0.3400 0.3050 0.4650 0.5525 0.5800 0.6800 0.7700],...
         [0 0.0260 0.1039 0.2944 0.6842 0.4893 0.4330 0.1905 0],'Color','k','LineWidth',[1.5]);
    plot([0.4550 0.5200 0.5450 0.6800],[0.0260 0.1905 0.2078 0.1905],'Color','k','LineWidth',[1.5]);
    plot([0.5200 0.4850 0.4500],[0.1905 0.2685 0.3031],'Color','k','LineWidth',[1.5]);
    plot([0.3400 0.4500 0.5800],[0.1039 0.3031 0.4330],'Color','k','LineWidth',[1.5]);
    plot([0.3400 0.4200 0.5525],[0.1039 0.4330 0.4893],'Color','k','LineStyle','--','LineWidth',[1.5]);
% Plot Text
    text(0.6,0.1,sprintf('VAB/\nNMORB'),'horizontalalignment','center',...
    'verticalalignment','middle','fontsize',10,'fontweight','b');
    text(0.44,0.16,sprintf('VAB/\nWPT'),'horizontalalignment','center',...
    'verticalalignment','middle','fontsize',10,'fontweight','b');
    text(0.57,0.28,sprintf('PMORB'),'horizontalalignment','center',...
    'verticalalignment','middle','fontsize',10,'fontweight','b');
    text(0.47,0.53,sprintf('WPA'),'horizontalalignment','center',...
    'verticalalignment','middle','fontsize',10,'fontweight','b');
    text(0.46,0.39,sprintf('WPA/\nWPT'),'horizontalalignment','center',...
    'verticalalignment','middle','fontsize',10,'fontweight','b');
    text(0.65,0.8,...
    sprintf('WPA - within-plate alkaline basalts\nWPT - within-plate tholeiitic basalts\nPMORB - plume-type MORB\nNMORB - normal-type MORB\nVAB - volcanic arc basalts'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
% Plot data
plot(a1Y,a1Nb,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none')
    hold off
% Axis titles
text(1.025,-0.04,'Y','horizontalalignment','center',...
    'verticalalignment','middle','fontsize',14,'fontweight','b');
text(-0.025,-0.04,'Zr/4','horizontalalignment','center',...
    'verticalalignment','middle','fontsize',14,'fontweight','b');
text(0.5,0.88,'2Nb','horizontalalignment', 'center',...
    'verticalalignment','middle','fontsize',14,'fontweight','b');
title('Zr/Nb/Y diagram (after Meschede, 1986)','fontsize',12,'fontweight','b')
set(gca,'dataaspectratio',[1 1 1]), axis off;
 
%% Clear data
clear meschede1
clear a1Nb a1Y
clear a1sum