% Generates the K2O vs. Na2O diagram (subdivision of alkaline series)
% after Middlemost (1975)
%
% Reference: Middlemost, E.A.K., 1975. The basalt clan. Earth-Science 
% Reviews 11, 337-364.
%
% Link: doi:10.1016/0012-8252(75)90039-2

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    cd(folder_plot)

    %% K2O vs. Na2O
% K2O vs. Na2O diagram
mid1 = figure('Visible','on','Position',[200,100,910,800]);
    movegui(mid1,'center')
    set(mid1,'Name','K2O vs. Na2O diagram - FGAPP v1.0 - 3 datasets')
% Generate the division line
plot([2 8],[8 2],'k--','LineWidth',2)
   hold all
plot([0.8 8],[0 5],'k-','LineWidth',2)
plot([0 5],[0.8 8],'k-','LineWidth',2)
    text(4.2,2,'Na - series','fontsize',16,'fontweight','b','Rotation',30)
    text(3.2,3.2,'K - series','fontsize',16,'fontweight','b','Rotation',42.5)
    text(2,4.2,'High-K - series','fontsize',16,'fontweight','b','Rotation',55)
    text(5,6.5,'Phonolitic Basalts','fontsize',16,'fontweight','b','Rotation',-42)
plot(n3Na2O,n3K2O,'v','MarkerEdgeColor','k',...
                    'MarkerFaceColor','g',...
                    'MarkerSize',6)
plot(n2Na2O,n2K2O,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1Na2O,n1K2O,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([0 8 0 8])
set(gca,'XTick',0:1:8,'FontWeight','bold','YTick',0:1:8,'LineWidth',2)
title('K_2O vs. Na_2O  diagram (after Middlemost, 1975)','fontsize',12,'fontweight','b')
xlabel('Na_2O [wt.%]','fontsize',12,'fontweight','b')
ylabel('K_2O [wt.%]','fontsize',12,'fontweight','b')

%% Clear data
clear mid1