%% Discrimination between peralkaline, metaluminous, and peraluminous rocks
%  using molecular Al2O3, Na2O, K2O, and CaO for four datasets

% Runs the generation script of the data
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)
    
% Calculation
   n1PI = (x1Na2O+x1K2O).\x1Al2O3;
   n1ASI = (x1Na2O+x1K2O+(x1CaO-1.67.*x1P2O5)).\x1Al2O3;
   n2PI = (x2Na2O+x2K2O).\x2Al2O3;
   n2ASI = (x2Na2O+x2K2O+(x2CaO-1.67.*x2P2O5)).\x2Al2O3;
   n3PI = (x3Na2O+x3K2O).\x3Al2O3;
   n3ASI = (x3Na2O+x3K2O+(x3CaO-1.67.*x3P2O5)).\x3Al2O3;
   n4PI = (x4Na2O+x4K2O).\x4Al2O3;
   n4ASI = (x4Na2O+x4K2O+(x4CaO-1.67.*x4P2O5)).\x4Al2O3;
   
% Generate grids
   ind1 = [0 4]; ind2 = [0 4]; ind3 = [1 1];

% PI vs. ASI diagram
molar4plot1 = figure('Visible','on','Position',[200,100,1280,800]);
    movegui(molar4plot1,'center')
    set(molar4plot1,'Name','PI vs. ASI - FGAPP v1.0 - 4 datasets')
plot(ind1,ind1,'k-',ind2,ind3,'k-',ind3,ind2,'k-','LineWidth',2)
text(0.5,0.75,'peralkaline','fontsize',12,'fontweight','b','HorizontalAlignment','center')
text(0.5,2,'metaluminous','fontsize',12,'fontweight','b','HorizontalAlignment','center')
text(1.5,2,'peraluminous','fontsize',12,'fontweight','b','HorizontalAlignment','center')
text(1.5,3.7,sprintf('PI = molar Al_2O_3/(Na_2O+K_2O) \nASI = molar Al_2O_3/(CaO-1.67*P_2O_5+Na_2O+K_2O)'),...
            'fontsize',10,'fontweight','b','HorizontalAlignment','left')
hold all
plot(n4ASI,n4PI,'^','MarkerEdgeColor','k',...
                    'MarkerFaceColor','y',...
                    'MarkerSize',6)
plot(n3ASI,n3PI,'v','MarkerEdgeColor','k',...
                    'MarkerFaceColor','g',...
                    'MarkerSize',6)
plot(n2ASI,n2PI,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1ASI,n1PI,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
hold off
axis ([0.25 4 0.25 4])
set(gca,'XTick',0.25:0.25:4)
set(gca,'YTick',0.25:0.25:4)
set(gca,'LineWidth',2,'fontsize',10,'fontweight','b')
title('Peraluminity Index (PI) vs. Alumina Saturation Index (ASI)','fontsize',12,'fontweight','b')
xlabel('ASI','fontsize',12,'fontweight','b')
ylabel('PI','fontsize',12,'fontweight','b')

    %% Clear data
clear ind1 ind2 ind3 molar4plot1
clear n1PI n1ASI n2PI n2ASI n3PI n3ASI n4PI n4ASI