%% Runs the normalization of rare earth elements for 4 datasets. 
% REE are normalized to C1-chondrite, primitive mantle,
% normal-type mid-ocean ridge basalts (NMORB), e-type MORB (EMORB), 
% and oceanic island basalts (OIB).
% 
% Normalizing values are taken from Sun & McDonough (1989)
%
% References: S.-S. Sun and W.F. Mc Donough, 1989. - Chemical and isotopic
% systematics of oceanic basalts: implications for mantle composition and
% processes. In: A.D. Saunders and M.J. Norry (Eds.), 1989. - Magmatism in
% the ocean basins, Geological Society Special Publication No. 42, pp.
% 313-345.

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)

%% C1-condrite normalization
% C1-condrite normalization values
La = 0.237;  Ce = 0.612;  Pr = 0.095;  Nd = 0.467; % Pm
Sm = 0.153;  Eu = 0.058;  Gd = 0.2055; Tb = 0.0374; 
Dy = 0.2540; Ho = 0.0566; Er = 0.1655; Tm = 0.0255;
Yb = 0.170;  Lu = 0.0254;
% Normalization
C1aLa = r1La./La; C1aCe = r1Ce./Ce; C1aPr = r1Pr./Pr; C1aNd = r1Nd./Nd; % Pm
C1aSm = r1Sm./Sm; C1aEu = r1Eu./Eu; C1aGd = r1Gd./Gd; C1aTb = r1Tb./Tb;
C1aDy = r1Dy./Dy; C1aHo = r1Ho./Ho; C1aEr = r1Er./Er; C1aTm = r1Tm./Tm;
C1aYb = r1Yb./Yb; C1aLu = r1Lu./Lu;
C1bLa = r2La./La; C1bCe = r2Ce./Ce; C1bPr = r2Pr./Pr; C1bNd = r2Nd./Nd; % Pm
C1bSm = r2Sm./Sm; C1bEu = r2Eu./Eu; C1bGd = r2Gd./Gd; C1bTb = r2Tb./Tb;
C1bDy = r2Dy./Dy; C1bHo = r2Ho./Ho; C1bEr = r2Er./Er; C1bTm = r2Tm./Tm;
C1bYb = r2Yb./Yb; C1bLu = r2Lu./Lu;
C1cLa = r3La./La; C1cCe = r3Ce./Ce; C1cPr = r3Pr./Pr; C1cNd = r3Nd./Nd; % Pm
C1cSm = r3Sm./Sm; C1cEu = r3Eu./Eu; C1cGd = r3Gd./Gd; C1cTb = r3Tb./Tb;
C1cDy = r3Dy./Dy; C1cHo = r3Ho./Ho; C1cEr = r3Er./Er; C1cTm = r3Tm./Tm;
C1cYb = r3Yb./Yb; C1cLu = r3Lu./Lu;
C1dLa = r4La./La; C1dCe = r4Ce./Ce; C1dPr = r4Pr./Pr; C1dNd = r4Nd./Nd; % Pm
C1dSm = r4Sm./Sm; C1dEu = r4Eu./Eu; C1dGd = r4Gd./Gd; C1dTb = r4Tb./Tb;
C1dDy = r4Dy./Dy; C1dHo = r4Ho./Ho; C1dEr = r4Er./Er; C1dTm = r4Tm./Tm;
C1dYb = r4Yb./Yb; C1dLu = r4Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); C1aPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); C1bPm = b.*NaN;
[h b] = size(r3La); b = ones(h,1); C1cPm = b.*NaN;
[h b] = size(r4La); b = ones(h,1); C1dPm = b.*NaN;
% Assemble all REE
C1anorm = [C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu];
C1bnorm = [C1bLa C1bCe C1bPr C1bNd C1bPm C1bSm C1bEu C1bGd C1bTb C1bDy C1bHo C1bEr C1bTm C1bYb C1bLu];
C1cnorm = [C1cLa C1cCe C1cPr C1cNd C1cPm C1cSm C1cEu C1cGd C1cTb C1cDy C1cHo C1cEr C1cTm C1cYb C1cLu];
C1dnorm = [C1dLa C1dCe C1dPr C1dNd C1dPm C1dSm C1dEu C1dGd C1dTb C1dDy C1dHo C1dEr C1dTm C1dYb C1dLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    C1ree4 = figure('Visible','on','Position',[100,100,900,800]);
    set(C1ree4,'Name','REE plots (C1-chondrite normalized) - FastGAPP v1.0 - 4 datasets')
semilogy(xax,C1dnorm,'LineStyle','-','Color','y','LineWidth',[2],'Marker','^',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','y')
                hold all
semilogy(xax,C1cnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
semilogy(xax,C1bnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax,C1anorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / C1-chondrite','fontsize',12,'fontweight','b')
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear C1anorm C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu
clear C1bnorm C1bLa C1bCe C1bPr C1bNd C1bPm C1bSm C1bEu C1bGd C1bTb C1bDy C1bHo C1bEr C1bTm C1bYb C1bLu
clear C1cnorm C1cLa C1cCe C1cPr C1cNd C1cPm C1cSm C1cEu C1cGd C1cTb C1cDy C1cHo C1cEr C1cTm C1cYb C1cLu
clear C1dnorm C1dLa C1dCe C1dPr C1dNd C1dPm C1dSm C1dEu C1dGd C1dTb C1dDy C1dHo C1dEr C1dTm C1dYb C1dLu
clear C1ree4

%% Primitive mantle normalization
% Primitive mantle normalization values
La = 0.687;  Ce = 1.775;  Pr = 0.276;  Nd = 1.354; % Pm
Sm = 0.444;  Eu = 0.168;  Gd = 0.596; Tb = 0.108; 
Dy = 0.737; Ho = 0.164; Er = 0.480; Tm = 0.074;
Yb = 0.493;  Lu = 0.074;
% Normalization
PMaLa = r1La./La; PMaCe = r1Ce./Ce; PMaPr = r1Pr./Pr; PMaNd = r1Nd./Nd; % Pm
PMaSm = r1Sm./Sm; PMaEu = r1Eu./Eu; PMaGd = r1Gd./Gd; PMaTb = r1Tb./Tb;
PMaDy = r1Dy./Dy; PMaHo = r1Ho./Ho; PMaEr = r1Er./Er; PMaTm = r1Tm./Tm;
PMaYb = r1Yb./Yb; PMaLu = r1Lu./Lu;
PMbLa = r2La./La; PMbCe = r2Ce./Ce; PMbPr = r2Pr./Pr; PMbNd = r2Nd./Nd; % Pm
PMbSm = r2Sm./Sm; PMbEu = r2Eu./Eu; PMbGd = r2Gd./Gd; PMbTb = r2Tb./Tb;
PMbDy = r2Dy./Dy; PMbHo = r2Ho./Ho; PMbEr = r2Er./Er; PMbTm = r2Tm./Tm;
PMbYb = r2Yb./Yb; PMbLu = r2Lu./Lu;
PMcLa = r3La./La; PMcCe = r3Ce./Ce; PMcPr = r3Pr./Pr; PMcNd = r3Nd./Nd; % Pm
PMcSm = r3Sm./Sm; PMcEu = r3Eu./Eu; PMcGd = r3Gd./Gd; PMcTb = r3Tb./Tb;
PMcDy = r3Dy./Dy; PMcHo = r3Ho./Ho; PMcEr = r3Er./Er; PMcTm = r3Tm./Tm;
PMcYb = r3Yb./Yb; PMcLu = r3Lu./Lu;
PMdLa = r4La./La; PMdCe = r4Ce./Ce; PMdPr = r4Pr./Pr; PMdNd = r4Nd./Nd; % Pm
PMdSm = r4Sm./Sm; PMdEu = r4Eu./Eu; PMdGd = r4Gd./Gd; PMdTb = r4Tb./Tb;
PMdDy = r4Dy./Dy; PMdHo = r4Ho./Ho; PMdEr = r4Er./Er; PMdTm = r4Tm./Tm;
PMdYb = r4Yb./Yb; PMdLu = r4Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); PMaPm = b.*NaN; 
[h b] = size(r2La); b = ones(h,1); PMbPm = b.*NaN;
[h b] = size(r3La); b = ones(h,1); PMcPm = b.*NaN;
[h b] = size(r4La); b = ones(h,1); PMdPm = b.*NaN;
% Assemble all REE
PManorm = [PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu];
PMbnorm = [PMbLa PMbCe PMbPr PMbNd PMbPm PMbSm PMbEu PMbGd PMbTb PMbDy PMbHo PMbEr PMbTm PMbYb PMbLu];
PMcnorm = [PMcLa PMcCe PMcPr PMcNd PMcPm PMcSm PMcEu PMcGd PMcTb PMcDy PMcHo PMcEr PMcTm PMcYb PMcLu];
PMdnorm = [PMdLa PMdCe PMdPr PMdNd PMdPm PMdSm PMdEu PMdGd PMdTb PMdDy PMdHo PMdEr PMdTm PMdYb PMdLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    PMree4 = figure('Visible','on','Position',[110,110,900,800]);
    set(PMree4,'Name','REE plots (primitive mantle normalized) - FastGAPP v1.0 - 4 datasets')
semilogy(xax,PMdnorm,'LineStyle','-','Color','y','LineWidth',[2],'Marker','^',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','y')
                hold all
semilogy(xax,PMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
semilogy(xax,PMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax,PManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / Primitive mantle','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear PManorm PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu
clear PMbnorm PMbLa PMbCe PMbPr PMbNd PMbPm PMbSm PMbEu PMbGd PMbTb PMbDy PMbHo PMbEr PMbTm PMbYb PMbLu
clear PMcnorm PMcLa PMcCe PMcPr PMcNd PMcPm PMcSm PMcEu PMcGd PMcTb PMcDy PMcHo PMcEr PMcTm PMcYb PMcLu
clear PMdnorm PMdLa PMdCe PMdPr PMdNd PMdPm PMdSm PMdEu PMdGd PMdTb PMdDy PMdHo PMdEr PMdTm PMdYb PMdLu
clear PMree4

%% N-MORB normalization
% N-MORB normalization values
La = 2.5;  Ce = 7.5;  Pr = 1.32;  Nd = 7.3; % Pm
Sm = 2.63;  Eu = 1.02;  Gd = 3.680; Tb = 0.670; 
Dy = 4.550; Ho = 1.01; Er = 2.97; Tm = 0.456;
Yb = 3.05;  Lu = 0.455;
% Normalization
NMaLa = r1La./La; NMaCe = r1Ce./Ce; NMaPr = r1Pr./Pr; NMaNd = r1Nd./Nd; % Pm
NMaSm = r1Sm./Sm; NMaEu = r1Eu./Eu; NMaGd = r1Gd./Gd; NMaTb = r1Tb./Tb;
NMaDy = r1Dy./Dy; NMaHo = r1Ho./Ho; NMaEr = r1Er./Er; NMaTm = r1Tm./Tm;
NMaYb = r1Yb./Yb; NMaLu = r1Lu./Lu;
NMbLa = r2La./La; NMbCe = r2Ce./Ce; NMbPr = r2Pr./Pr; NMbNd = r2Nd./Nd; % Pm
NMbSm = r2Sm./Sm; NMbEu = r2Eu./Eu; NMbGd = r2Gd./Gd; NMbTb = r2Tb./Tb;
NMbDy = r2Dy./Dy; NMbHo = r2Ho./Ho; NMbEr = r2Er./Er; NMbTm = r2Tm./Tm;
NMbYb = r2Yb./Yb; NMbLu = r2Lu./Lu;
NMcLa = r3La./La; NMcCe = r3Ce./Ce; NMcPr = r3Pr./Pr; NMcNd = r3Nd./Nd; % Pm
NMcSm = r3Sm./Sm; NMcEu = r3Eu./Eu; NMcGd = r3Gd./Gd; NMcTb = r3Tb./Tb;
NMcDy = r3Dy./Dy; NMcHo = r3Ho./Ho; NMcEr = r3Er./Er; NMcTm = r3Tm./Tm;
NMcYb = r3Yb./Yb; NMcLu = r3Lu./Lu;
NMdLa = r4La./La; NMdCe = r4Ce./Ce; NMdPr = r4Pr./Pr; NMdNd = r4Nd./Nd; % Pm
NMdSm = r4Sm./Sm; NMdEu = r4Eu./Eu; NMdGd = r4Gd./Gd; NMdTb = r4Tb./Tb;
NMdDy = r4Dy./Dy; NMdHo = r4Ho./Ho; NMdEr = r4Er./Er; NMdTm = r4Tm./Tm;
NMdYb = r4Yb./Yb; NMdLu = r4Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); NMaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); NMbPm = b.*NaN;
[h b] = size(r3La); b = ones(h,1); NMcPm = b.*NaN;
[h b] = size(r4La); b = ones(h,1); NMdPm = b.*NaN;
% Assemble all REE
NManorm = [NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu];
NMbnorm = [NMbLa NMbCe NMbPr NMbNd NMbPm NMbSm NMbEu NMbGd NMbTb NMbDy NMbHo NMbEr NMbTm NMbYb NMbLu];
NMcnorm = [NMcLa NMcCe NMcPr NMcNd NMcPm NMcSm NMcEu NMcGd NMcTb NMcDy NMcHo NMcEr NMcTm NMcYb NMcLu];
NMdnorm = [NMdLa NMdCe NMdPr NMdNd NMdPm NMdSm NMdEu NMdGd NMdTb NMdDy NMdHo NMdEr NMdTm NMdYb NMdLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    NMORBree4 = figure('Visible','on','Position',[120,120,900,800]);
    set(NMORBree4,'Name','REE plots (N-type MORB normalized) - FastGAPP v1.0 - 4 datasets')
semilogy(xax,NMdnorm,'LineStyle','-','Color','y','LineWidth',[2],'Marker','^',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','y')
                hold all
semilogy(xax,NMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
semilogy(xax,NMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax,NManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / NMORB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear NManorm NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu
clear NMbnorm NMbLa NMbCe NMbPr NMbNd NMbPm NMbSm NMbEu NMbGd NMbTb NMbDy NMbHo NMbEr NMbTm NMbYb NMbLu
clear NMcnorm NMcLa NMcCe NMcPr NMcNd NMcPm NMcSm NMcEu NMcGd NMcTb NMcDy NMcHo NMcEr NMcTm NMcYb NMcLu
clear NMdnorm NMdLa NMdCe NMdPr NMdNd NMdPm NMdSm NMdEu NMdGd NMdTb NMdDy NMdHo NMdEr NMdTm NMdYb NMdLu
clear NMORBree4

%% E-MORB normalization
% E-MORB normalization values
La = 6.3;  Ce = 15.0;  Pr = 2.05;  Nd = 9.00; % Pm
Sm = 2.60;  Eu = 0.91;  Gd = 2.970; Tb = 0.530; 
Dy = 3.550; Ho = 0.790; Er = 2.31; Tm = 0.356;
Yb = 2.37;  Lu = 0.354;
% Normalization
EMaLa = r1La./La; EMaCe = r1Ce./Ce; EMaPr = r1Pr./Pr; EMaNd = r1Nd./Nd; % Pm
EMaSm = r1Sm./Sm; EMaEu = r1Eu./Eu; EMaGd = r1Gd./Gd; EMaTb = r1Tb./Tb;
EMaDy = r1Dy./Dy; EMaHo = r1Ho./Ho; EMaEr = r1Er./Er; EMaTm = r1Tm./Tm;
EMaYb = r1Yb./Yb; EMaLu = r1Lu./Lu;
EMbLa = r2La./La; EMbCe = r2Ce./Ce; EMbPr = r2Pr./Pr; EMbNd = r2Nd./Nd; % Pm
EMbSm = r2Sm./Sm; EMbEu = r2Eu./Eu; EMbGd = r2Gd./Gd; EMbTb = r2Tb./Tb;
EMbDy = r2Dy./Dy; EMbHo = r2Ho./Ho; EMbEr = r2Er./Er; EMbTm = r2Tm./Tm;
EMbYb = r2Yb./Yb; EMbLu = r2Lu./Lu;
EMcLa = r3La./La; EMcCe = r3Ce./Ce; EMcPr = r3Pr./Pr; EMcNd = r3Nd./Nd; % Pm
EMcSm = r3Sm./Sm; EMcEu = r3Eu./Eu; EMcGd = r3Gd./Gd; EMcTb = r3Tb./Tb;
EMcDy = r3Dy./Dy; EMcHo = r3Ho./Ho; EMcEr = r3Er./Er; EMcTm = r3Tm./Tm;
EMcYb = r3Yb./Yb; EMcLu = r3Lu./Lu;
EMdLa = r4La./La; EMdCe = r4Ce./Ce; EMdPr = r4Pr./Pr; EMdNd = r4Nd./Nd; % Pm
EMdSm = r4Sm./Sm; EMdEu = r4Eu./Eu; EMdGd = r4Gd./Gd; EMdTb = r4Tb./Tb;
EMdDy = r4Dy./Dy; EMdHo = r4Ho./Ho; EMdEr = r4Er./Er; EMdTm = r4Tm./Tm;
EMdYb = r4Yb./Yb; EMdLu = r4Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); EMaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); EMbPm = b.*NaN;
[h b] = size(r3La); b = ones(h,1); EMcPm = b.*NaN;
[h b] = size(r4La); b = ones(h,1); EMdPm = b.*NaN;
% Assemble all REE
EManorm = [EMaLa EMaCe EMaPr EMaNd EMaPm EMaSm EMaEu EMaGd EMaTb EMaDy EMaHo EMaEr EMaTm EMaYb EMaLu];
EMbnorm = [EMbLa EMbCe EMbPr EMbNd EMbPm EMbSm EMbEu EMbGd EMbTb EMbDy EMbHo EMbEr EMbTm EMbYb EMbLu];
EMcnorm = [EMcLa EMcCe EMcPr EMcNd EMcPm EMcSm EMcEu EMcGd EMcTb EMcDy EMcHo EMcEr EMcTm EMcYb EMcLu];
EMdnorm = [EMdLa EMdCe EMdPr EMdNd EMdPm EMdSm EMdEu EMdGd EMdTb EMdDy EMdHo EMdEr EMdTm EMdYb EMdLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    EMORBree4 = figure('Visible','on','Position',[130,130,900,800]);
    set(EMORBree4,'Name','REE plots (E-type MORB normalized) - FastGAPP v1.0 - 4 datasets')
semilogy(xax,EMdnorm,'LineStyle','-','Color','y','LineWidth',[2],'Marker','^',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','y')
                hold all
semilogy(xax,EMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
semilogy(xax,EMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax,EManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / EMORB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear EManorm EMaLa EMaCe EMaPr EMaNd EMaPm EMaSm EMaEu EMaGd EMaTb EMaDy EMaHo EMaEr EMaTm EMaYb EMaLu
clear EMbnorm EMbLa EMbCe EMbPr EMbNd EMbPm EMbSm EMbEu EMbGd EMbTb EMbDy EMbHo EMbEr EMbTm EMbYb EMbLu
clear EMcnorm EMcLa EMcCe EMcPr EMcNd EMcPm EMcSm EMcEu EMcGd EMcTb EMcDy EMcHo EMcEr EMcTm EMcYb EMcLu
clear EMdnorm EMdLa EMdCe EMdPr EMdNd EMdPm EMdSm EMdEu EMdGd EMdTb EMdDy EMdHo EMdEr EMdTm EMdYb EMdLu
clear EMORBree4

%% OIB normalization
% OIB normalization values
La = 37.0;  Ce = 80.0;  Pr = 9.7;  Nd = 38.5; % Pm
Sm = 10.0;  Eu = 3.0;  Gd = 7.620; Tb = 1.050; 
Dy = 5.600; Ho = 1.06; Er = 2.62; Tm = 0.350;
Yb = 2.16;  Lu = 0.3;
% Normalization
OIBaLa = r1La./La; OIBaCe = r1Ce./Ce; OIBaPr = r1Pr./Pr; OIBaNd = r1Nd./Nd; % Pm
OIBaSm = r1Sm./Sm; OIBaEu = r1Eu./Eu; OIBaGd = r1Gd./Gd; OIBaTb = r1Tb./Tb;
OIBaDy = r1Dy./Dy; OIBaHo = r1Ho./Ho; OIBaEr = r1Er./Er; OIBaTm = r1Tm./Tm;
OIBaYb = r1Yb./Yb; OIBaLu = r1Lu./Lu;
OIBbLa = r2La./La; OIBbCe = r2Ce./Ce; OIBbPr = r2Pr./Pr; OIBbNd = r2Nd./Nd; % Pm
OIBbSm = r2Sm./Sm; OIBbEu = r2Eu./Eu; OIBbGd = r2Gd./Gd; OIBbTb = r2Tb./Tb;
OIBbDy = r2Dy./Dy; OIBbHo = r2Ho./Ho; OIBbEr = r2Er./Er; OIBbTm = r2Tm./Tm;
OIBbYb = r2Yb./Yb; OIBbLu = r2Lu./Lu;
OIBcLa = r3La./La; OIBcCe = r3Ce./Ce; OIBcPr = r3Pr./Pr; OIBcNd = r3Nd./Nd; % Pm
OIBcSm = r3Sm./Sm; OIBcEu = r3Eu./Eu; OIBcGd = r3Gd./Gd; OIBcTb = r3Tb./Tb;
OIBcDy = r3Dy./Dy; OIBcHo = r3Ho./Ho; OIBcEr = r3Er./Er; OIBcTm = r3Tm./Tm;
OIBcYb = r3Yb./Yb; OIBcLu = r3Lu./Lu;
OIBdLa = r4La./La; OIBdCe = r4Ce./Ce; OIBdPr = r4Pr./Pr; OIBdNd = r4Nd./Nd; % Pm
OIBdSm = r4Sm./Sm; OIBdEu = r4Eu./Eu; OIBdGd = r4Gd./Gd; OIBdTb = r4Tb./Tb;
OIBdDy = r4Dy./Dy; OIBdHo = r4Ho./Ho; OIBdEr = r4Er./Er; OIBdTm = r4Tm./Tm;
OIBdYb = r4Yb./Yb; OIBdLu = r4Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); OIBaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); OIBbPm = b.*NaN;
[h b] = size(r3La); b = ones(h,1); OIBcPm = b.*NaN;
[h b] = size(r4La); b = ones(h,1); OIBdPm = b.*NaN;
% Assemble all REE
OIBanorm = [OIBaLa OIBaCe OIBaPr OIBaNd OIBaPm OIBaSm OIBaEu OIBaGd OIBaTb OIBaDy OIBaHo OIBaEr OIBaTm OIBaYb OIBaLu];
OIBbnorm = [OIBbLa OIBbCe OIBbPr OIBbNd OIBbPm OIBbSm OIBbEu OIBbGd OIBbTb OIBbDy OIBbHo OIBbEr OIBbTm OIBbYb OIBbLu];
OIBcnorm = [OIBcLa OIBcCe OIBcPr OIBcNd OIBcPm OIBcSm OIBcEu OIBcGd OIBcTb OIBcDy OIBcHo OIBcEr OIBcTm OIBcYb OIBcLu];
OIBdnorm = [OIBdLa OIBdCe OIBdPr OIBdNd OIBdPm OIBdSm OIBdEu OIBdGd OIBdTb OIBdDy OIBdHo OIBdEr OIBdTm OIBdYb OIBdLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    OIBree4 = figure('Visible','on','Position',[140,140,900,800]);
    set(OIBree4,'Name','REE plots (OIB normalized) - FastGAPP v1.0 - 4 datasets')
semilogy(xax,OIBdnorm,'LineStyle','-','Color','y','LineWidth',[2],'Marker','^',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','y') 
                hold all
semilogy(xax,OIBcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')       
semilogy(xax,OIBbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b') 
semilogy(xax,OIBanorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / OIB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear OIBanorm OIBaLa OIBaCe OIBaPr OIBaNd OIBaPm OIBaSm OIBaEu OIBaGd OIBaTb OIBaDy OIBaHo OIBaEr OIBaTm OIBaYb OIBaLu
clear OIBbnorm OIBbLa OIBbCe OIBbPr OIBbNd OIBbPm OIBbSm OIBbEu OIBbGd OIBbTb OIBbDy OIBbHo OIBbEr OIBbTm OIBbYb OIBbLu
clear OIBcnorm OIBcLa OIBcCe OIBcPr OIBcNd OIBcPm OIBcSm OIBcEu OIBcGd OIBcTb OIBcDy OIBcHo OIBcEr OIBcTm OIBcYb OIBcLu
clear OIBdnorm OIBdLa OIBdCe OIBdPr OIBdNd OIBdPm OIBdSm OIBdEu OIBdGd OIBdTb OIBdDy OIBdHo OIBdEr OIBdTm OIBdYb OIBdLu
clear OIBree4
