%% Runs the normalization of Spider-diagram for 3 datasets. 
% Elements are normalized to C1-chondrite, primitive mantle,
% normal-type mid-ocean ridge basalts (NMORB), e-type MORB (EMORB), 
% and oceanic island basalts (OIB).
% 
% Normalizing values are taken from Sun & McDonough (1989)
%
% References: S.-S. Sun and W.F. Mc Donough, 1989. - Chemical and isotopic
% systematics of oceanic basalts: implications for mantle composition and
% processes. In: A.D. Saunders and M.J. Norry (Eds.), 1989. - Magmatism in
% the ocean basins, Geological Society Special Publication No. 42, pp.
% 313-345.

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    cd(folder_plot)

%% C1-condrite normalization
% C1-condrite normalization values
Cs = 0.188;  Rb = 2.32;   Ba = 2.41;   Th = 0.029;  U = 0.008;  Nb = 0.246;
Ta = 0.014;  K  = 545;    La = 0.237;  Ce = 0.612;  Pb= 2.47;   Pr = 0.095;  
Sr = 7.26;   P = 1220;    Nd = 0.467;  Zr = 3.87;   Sm = 0.153; Eu = 0.058;  
Ti = 445;    Dy = 0.2540; Y  = 1.57;   Ho = 0.0566; Yb = 0.170; Lu = 0.0254;
% Normalization
C1aCs = r1Cs./Cs; C1aRb = r1Rb./Rb; C1aBa = r1Ba./Ba; C1aTh = r1Th./Th;
C1aU  = r1U./U;   C1aNb = r1Nb./Nb; 
C1aTa = r1Ta./Ta; C1aK  = (r1K2O.*10000.*0.8301)./K; C1aLa = r1La./La; C1aCe = r1Ce./Ce;
C1aPb = r1Pb./Pb; C1aPr = r1Pr./Pr; 
C1aSr = r1Sr./Sr; C1aP = (r1P2O5.*10000.*0.4364)./P; C1aNd = r1Nd./Nd; C1aZr = r1Zr./Zr;
C1aSm = r1Sm./Sm; C1aEu = r1Eu./Eu;
C1aTi = (r1TiO2.*10000.*0.5993)./Ti; C1aDy = r1Dy./Dy; C1aY = r1Y./Y; C1aHo = r1Ho./Ho;
C1aYb = r1Yb./Yb; C1aLu = r1Lu./Lu;
C1anorm = [C1aCs C1aRb C1aBa C1aTh C1aU C1aNb C1aTa C1aK C1aLa C1aCe C1aPb C1aPr C1aSr C1aP C1aNd C1aZr C1aSm C1aEu C1aTi C1aDy C1aY C1aHo C1aYb C1aLu];
clear C1aCs C1aRb C1aBa C1aTh C1aU C1aNb C1aTa C1aK C1aLa C1aCe C1aPb C1aPr C1aSr C1aP C1aNd C1aZr C1aSm C1aEu C1aTi C1aDy C1aY C1aHo C1aYb C1aLu
C1bCs = r2Cs./Cs; C1bRb = r2Rb./Rb; C1bBa = r2Ba./Ba; C1bTh = r2Th./Th;
C1bU  = r2U./U;   C1bNb = r2Nb./Nb; 
C1bTa = r2Ta./Ta; C1bK  = (r2K2O.*10000.*0.8301)./K; C1bLa = r2La./La; C1bCe = r2Ce./Ce;
C1bPb = r2Pb./Pb; C1bPr = r2Pr./Pr; 
C1bSr = r2Sr./Sr; C1bP = (r2P2O5.*10000.*0.4364)./P; C1bNd = r2Nd./Nd; C1bZr = r2Zr./Zr;
C1bSm = r2Sm./Sm; C1bEu = r2Eu./Eu;
C1bTi = (r2TiO2.*10000.*0.5993)./Ti; C1bDy = r2Dy./Dy; C1bY = r2Y./Y; C1bHo = r2Ho./Ho;
C1bYb = r2Yb./Yb; C1bLu = r2Lu./Lu;
C1bnorm = [C1bCs C1bRb C1bBa C1bTh C1bU C1bNb C1bTa C1bK C1bLa C1bCe C1bPb C1bPr C1bSr C1bP C1bNd C1bZr C1bSm C1bEu C1bTi C1bDy C1bY C1bHo C1bYb C1bLu];
clear C1bCs C1bRb C1bBa C1bTh C1bU C1bNb C1bTa C1bK C1bLa C1bCe C1bPb C1bPr C1bSr C1bP C1bNd C1bZr C1bSm C1bEu C1bTi C1bDy C1bY C1bHo C1bYb C1bLu
C1cCs = r3Cs./Cs; C1cRb = r3Rb./Rb; C1cBa = r3Ba./Ba; C1cTh = r3Th./Th;
C1cU  = r3U./U;   C1cNb = r3Nb./Nb; 
C1cTa = r3Ta./Ta; C1cK  = (r3K2O.*10000.*0.8301)./K; C1cLa = r3La./La; C1cCe = r3Ce./Ce;
C1cPb = r3Pb./Pb; C1cPr = r3Pr./Pr; 
C1cSr = r3Sr./Sr; C1cP = (r3P2O5.*10000.*0.4364)./P; C1cNd = r3Nd./Nd; C1cZr = r3Zr./Zr;
C1cSm = r3Sm./Sm; C1cEu = r3Eu./Eu;
C1cTi = (r3TiO2.*10000.*0.5993)./Ti; C1cDy = r3Dy./Dy; C1cY = r3Y./Y; C1cHo = r3Ho./Ho;
C1cYb = r3Yb./Yb; C1cLu = r3Lu./Lu;
C1cnorm = [C1cCs C1cRb C1cBa C1cTh C1cU C1cNb C1cTa C1cK C1cLa C1cCe C1cPb C1cPr C1cSr C1cP C1cNd C1cZr C1cSm C1cEu C1cTi C1cDy C1cY C1cHo C1cYb C1cLu];
clear C1cCs C1cRb C1cBa C1cTh C1cU C1cNb C1cTa C1cK C1cLa C1cCe C1cPb C1cPr C1cSr C1cP C1cNd C1cZr C1cSm C1cEu C1cTi C1cDy C1cY C1cHo C1cYb C1cLu
% Create x-axis
xax2    = [1:24];
spitext = {'Cs' 'Rb' 'Ba' 'Th' 'U' 'Nb' 'Ta' 'K' 'La' 'Ce' 'Pb' 'Pr' 'Sr' 'P' 'Nd' 'Zr' 'Sm' 'Eu' 'Ti' 'Dy' 'Y' 'Ho' 'Yb' 'Lu'};
clear Cs Rb Ba Th U Nb Ta K La Ce Pb Pr Sr P Nd Zr Sm Eu Ti Dy Y Ho Yb Lu
% Create the figure
    C1spi4 = figure('Visible','on','Position',[100,100,900,800]);
    set(C1spi4,'Name','Spider plots (C1-chondrite normalized) - FastGAPP v1.0 - 3 datasets')
semilogy(xax2,C1cnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
                hold all
semilogy(xax2,C1bnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax2,C1anorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 24.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1:1:24],...
          'XTickLabel',spitext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[1 10 100 1000],...
          'YTickLabel',[1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('Spider plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / C1-chondrite','fontsize',12,'fontweight','b')
% Clear data
clear xax2 spitext
clear C1anorm C1bnorm C1cnorm C1spi4

%% Primitive mantle normalization
% Primitive mantle normalization values
Cs = 0.0079;  Rb = 0.635;   Ba = 6.989;   Th = 0.085;  U = 0.021;  Nb = 0.713;
Ta = 0.041;  K  = 250;    La = 0.687;  Ce = 1.775;  Pb = 0.071;   Pr = 0.276;  
Sr = 21.1;   P = 95;    Nd = 1.354;  Zr = 11.2;   Sm = 0.444; Eu = 0.168;  
Ti = 1300;    Dy = 0.737; Y  = 4.55;   Ho = 0.164; Yb = 0.493; Lu = 0.074;
% Normalization
PMaCs = r1Cs./Cs; PMaRb = r1Rb./Rb; PMaBa = r1Ba./Ba; PMaTh = r1Th./Th;
PMaU  = r1U./U;   PMaNb = r1Nb./Nb; 
PMaTa = r1Ta./Ta; PMaK  = (r1K2O.*10000.*0.8301)./K; PMaLa = r1La./La; PMaCe = r1Ce./Ce;
PMaPb = r1Pb./Pb; PMaPr = r1Pr./Pr; 
PMaSr = r1Sr./Sr; PMaP = (r1P2O5.*10000.*0.4364)./P; PMaNd = r1Nd./Nd; PMaZr = r1Zr./Zr;
PMaSm = r1Sm./Sm; PMaEu = r1Eu./Eu;
PMaTi = (r1TiO2.*10000.*0.5993)./Ti; PMaDy = r1Dy./Dy; PMaY = r1Y./Y; PMaHo = r1Ho./Ho;
PMaYb = r1Yb./Yb; PMaLu = r1Lu./Lu;
PManorm = [PMaCs PMaRb PMaBa PMaTh PMaU PMaNb PMaTa PMaK PMaLa PMaCe PMaPb PMaPr PMaSr PMaP PMaNd PMaZr PMaSm PMaEu PMaTi PMaDy PMaY PMaHo PMaYb PMaLu];
clear PMaCs PMaRb PMaBa PMaTh PMaU PMaNb PMaTa PMaK PMaLa PMaCe PMaPb PMaPr PMaSr PMaP PMaNd PMaZr PMaSm PMaEu PMaTi PMaDy PMaY PMaHo PMaYb PMaLu
PMbCs = r2Cs./Cs; PMbRb = r2Rb./Rb; PMbBa = r2Ba./Ba; PMbTh = r2Th./Th;
PMbU  = r2U./U;   PMbNb = r2Nb./Nb; 
PMbTa = r2Ta./Ta; PMbK  = (r2K2O.*10000.*0.8301)./K; PMbLa = r2La./La; PMbCe = r2Ce./Ce;
PMbPb = r2Pb./Pb; PMbPr = r2Pr./Pr; 
PMbSr = r2Sr./Sr; PMbP = (r2P2O5.*10000.*0.4364)./P; PMbNd = r2Nd./Nd; PMbZr = r2Zr./Zr;
PMbSm = r2Sm./Sm; PMbEu = r2Eu./Eu;
PMbTi = (r2TiO2.*10000.*0.5993)./Ti; PMbDy = r2Dy./Dy; PMbY = r2Y./Y; PMbHo = r2Ho./Ho;
PMbYb = r2Yb./Yb; PMbLu = r2Lu./Lu;
PMbnorm = [PMbCs PMbRb PMbBa PMbTh PMbU PMbNb PMbTa PMbK PMbLa PMbCe PMbPb PMbPr PMbSr PMbP PMbNd PMbZr PMbSm PMbEu PMbTi PMbDy PMbY PMbHo PMbYb PMbLu];
clear PMbCs PMbRb PMbBa PMbTh PMbU PMbNb PMbTa PMbK PMbLa PMbCe PMbPb PMbPr PMbSr PMbP PMbNd PMbZr PMbSm PMbEu PMbTi PMbDy PMbY PMbHo PMbYb PMbLu
PMcCs = r3Cs./Cs; PMcRb = r3Rb./Rb; PMcBa = r3Ba./Ba; PMcTh = r3Th./Th;
PMcU  = r3U./U;   PMcNb = r3Nb./Nb; 
PMcTa = r3Ta./Ta; PMcK  = (r3K2O.*10000.*0.8301)./K; PMcLa = r3La./La; PMcCe = r3Ce./Ce;
PMcPb = r3Pb./Pb; PMcPr = r3Pr./Pr; 
PMcSr = r3Sr./Sr; PMcP = (r3P2O5.*10000.*0.4364)./P; PMcNd = r3Nd./Nd; PMcZr = r3Zr./Zr;
PMcSm = r3Sm./Sm; PMcEu = r3Eu./Eu;
PMcTi = (r3TiO2.*10000.*0.5993)./Ti; PMcDy = r3Dy./Dy; PMcY = r3Y./Y; PMcHo = r3Ho./Ho;
PMcYb = r3Yb./Yb; PMcLu = r3Lu./Lu;
PMcnorm = [PMcCs PMcRb PMcBa PMcTh PMcU PMcNb PMcTa PMcK PMcLa PMcCe PMcPb PMcPr PMcSr PMcP PMcNd PMcZr PMcSm PMcEu PMcTi PMcDy PMcY PMcHo PMcYb PMcLu];
clear PMcCs PMcRb PMcBa PMcTh PMcU PMcNb PMcTa PMcK PMcLa PMcCe PMcPb PMcPr PMcSr PMcP PMcNd PMcZr PMcSm PMcEu PMcTi PMcDy PMcY PMcHo PMcYb PMcLu
% Create x-axis
xax2    = [1:24];
spitext = {'Cs' 'Rb' 'Ba' 'Th' 'U' 'Nb' 'Ta' 'K' 'La' 'Ce' 'Pb' 'Pr' 'Sr' 'P' 'Nd' 'Zr' 'Sm' 'Eu' 'Ti' 'Dy' 'Y' 'Ho' 'Yb' 'Lu'};
clear Cs Rb Ba Th U Nb Ta K La Ce Pb Pr Sr P Nd Zr Sm Eu Ti Dy Y Ho Yb Lu
% Create the figure
    PMspi4 = figure('Visible','on','Position',[110,110,900,800]);
    set(PMspi4,'Name','Spider plots (primitive mantle normalized) - FastGAPP v1.0 - 3 datasets')
semilogy(xax2,PMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
                hold all
semilogy(xax2,PMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax2,PManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 24.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1:1:24],...
          'XTickLabel',spitext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[1 10 100 1000],...
          'YTickLabel',[1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('Spider plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / Primitive mantle','fontsize',12,'fontweight','b')
% Clear data
clear xax2 spitext
clear PManorm PMbnorm PMcnorm PMspi4

%% N-MORB normalization
% N-MORB normalization values
Cs = 0.0070;  Rb = 0.56;   Ba = 6.3;   Th = 0.120;  U = 0.047;  Nb = 2.33;
Ta = 0.132;  K  = 600;    La = 2.5;  Ce = 7.5;  Pb = 0.30;   Pr = 1.32;  
Sr = 90;   P = 510;    Nd = 7.3;  Zr = 74;   Sm = 2.63;  Eu = 1.02;  
Ti = 7600;    Dy = 4.550; Y  = 28;   Ho = 1.01; Yb = 3.05; Lu = 0.455;
% % Normalization
NMaCs = r1Cs./Cs; NMaRb = r1Rb./Rb; NMaBa = r1Ba./Ba; NMaTh = r1Th./Th;
NMaU  = r1U./U;   NMaNb = r1Nb./Nb; 
NMaTa = r1Ta./Ta; NMaK  = (r1K2O.*10000.*0.8301)./K; NMaLa = r1La./La; NMaCe = r1Ce./Ce;
NMaPb = r1Pb./Pb; NMaPr = r1Pr./Pr; 
NMaSr = r1Sr./Sr; NMaP = (r1P2O5.*10000.*0.4364)./P; NMaNd = r1Nd./Nd; NMaZr = r1Zr./Zr;
NMaSm = r1Sm./Sm; NMaEu = r1Eu./Eu;
NMaTi = (r1TiO2.*10000.*0.5993)./Ti; NMaDy = r1Dy./Dy; NMaY = r1Y./Y; NMaHo = r1Ho./Ho;
NMaYb = r1Yb./Yb; NMaLu = r1Lu./Lu;
NManorm = [NMaCs NMaRb NMaBa NMaTh NMaU NMaNb NMaTa NMaK NMaLa NMaCe NMaPb NMaPr NMaSr NMaP NMaNd NMaZr NMaSm NMaEu NMaTi NMaDy NMaY NMaHo NMaYb NMaLu];
clear NMaCs NMaRb NMaBa NMaTh NMaU NMaNb NMaTa NMaK NMaLa NMaCe NMaPb NMaPr NMaSr NMaP NMaNd NMaZr NMaSm NMaEu NMaTi NMaDy NMaY NMaHo NMaYb NMaLu
NMbCs = r2Cs./Cs; NMbRb = r2Rb./Rb; NMbBa = r2Ba./Ba; NMbTh = r2Th./Th;
NMbU  = r2U./U;   NMbNb = r2Nb./Nb; 
NMbTa = r2Ta./Ta; NMbK  = (r2K2O.*10000.*0.8301)./K; NMbLa = r2La./La; NMbCe = r2Ce./Ce;
NMbPb = r2Pb./Pb; NMbPr = r2Pr./Pr; 
NMbSr = r2Sr./Sr; NMbP = (r2P2O5.*10000.*0.4364)./P; NMbNd = r2Nd./Nd; NMbZr = r2Zr./Zr;
NMbSm = r2Sm./Sm; NMbEu = r2Eu./Eu;
NMbTi = (r2TiO2.*10000.*0.5993)./Ti; NMbDy = r2Dy./Dy; NMbY = r2Y./Y; NMbHo = r2Ho./Ho;
NMbYb = r2Yb./Yb; NMbLu = r2Lu./Lu;
NMbnorm = [NMbCs NMbRb NMbBa NMbTh NMbU NMbNb NMbTa NMbK NMbLa NMbCe NMbPb NMbPr NMbSr NMbP NMbNd NMbZr NMbSm NMbEu NMbTi NMbDy NMbY NMbHo NMbYb NMbLu];
clear NMbCs NMbRb NMbBa NMbTh NMbU NMbNb NMbTa NMbK NMbLa NMbCe NMbPb NMbPr NMbSr NMbP NMbNd NMbZr NMbSm NMbEu NMbTi NMbDy NMbY NMbHo NMbYb NMbLu
NMcCs = r3Cs./Cs; NMcRb = r3Rb./Rb; NMcBa = r3Ba./Ba; NMcTh = r3Th./Th;
NMcU  = r3U./U;   NMcNb = r3Nb./Nb; 
NMcTa = r3Ta./Ta; NMcK  = (r3K2O.*10000.*0.8301)./K; NMcLa = r3La./La; NMcCe = r3Ce./Ce;
NMcPb = r3Pb./Pb; NMcPr = r3Pr./Pr; 
NMcSr = r3Sr./Sr; NMcP = (r3P2O5.*10000.*0.4364)./P; NMcNd = r3Nd./Nd; NMcZr = r3Zr./Zr;
NMcSm = r3Sm./Sm; NMcEu = r3Eu./Eu;
NMcTi = (r3TiO2.*10000.*0.5993)./Ti; NMcDy = r3Dy./Dy; NMcY = r3Y./Y; NMcHo = r3Ho./Ho;
NMcYb = r3Yb./Yb; NMcLu = r3Lu./Lu;
NMcnorm = [NMcCs NMcRb NMcBa NMcTh NMcU NMcNb NMcTa NMcK NMcLa NMcCe NMcPb NMcPr NMcSr NMcP NMcNd NMcZr NMcSm NMcEu NMcTi NMcDy NMcY NMcHo NMcYb NMcLu];
clear NMcCs NMcRb NMcBa NMcTh NMcU NMcNb NMcTa NMcK NMcLa NMcCe NMcPb NMcPr NMcSr NMcP NMcNd NMcZr NMcSm NMcEu NMcTi NMcDy NMcY NMcHo NMcYb NMcLu
% Create x-axis
xax2    = [1:24];
spitext = {'Cs' 'Rb' 'Ba' 'Th' 'U' 'Nb' 'Ta' 'K' 'La' 'Ce' 'Pb' 'Pr' 'Sr' 'P' 'Nd' 'Zr' 'Sm' 'Eu' 'Ti' 'Dy' 'Y' 'Ho' 'Yb' 'Lu'};
clear Cs Rb Ba Th U Nb Ta K La Ce Pb Pr Sr P Nd Zr Sm Eu Ti Dy Y Ho Yb Lu
% Create the figure
    NMORBspi4 = figure('Visible','on','Position',[120,120,900,800]);
    set(NMORBspi4,'Name','Spider plots (N-type MORB normalized) - FastGAPP v1.0 - 3 datasets')
semilogy(xax2,NMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g') 
                hold all
semilogy(xax2,NMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax2,NManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 24.25 0.1 1000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1:1:24],...
          'XTickLabel',spitext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('Spider plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / NMORB','fontsize',12,'fontweight','b')
% Clear data
clear xax2 spitext
clear NManorm NMbnorm NMcnorm NMORBspi4

%% E-MORB normalization
% E-MORB normalization values
Cs = 0.063;  Rb = 5.04;   Ba = 57;   Th = 0.60;  U = 0.18;  Nb = 8.30;
Ta = 0.47;  K  = 2100;    La = 6.3;  Ce = 15.0;  Pb = 0.60;   Pr = 2.05;  
Sr = 155;   P = 620;    Nd = 9.00;  Zr = 73;   Sm = 2.60;  Eu = 0.91;  
Ti = 6000;    Dy = 3.550; Y  = 22;   Ho = 0.790; Yb = 2.37; Lu = 0.354;
% Normalization
EMaCs = r1Cs./Cs; EMaRb = r1Rb./Rb; EMaBa = r1Ba./Ba; EMaTh = r1Th./Th;
EMaU  = r1U./U;   EMaNb = r1Nb./Nb; 
EMaTa = r1Ta./Ta; EMaK  = (r1K2O.*10000.*0.8301)./K; EMaLa = r1La./La; EMaCe = r1Ce./Ce;
EMaPb = r1Pb./Pb; EMaPr = r1Pr./Pr; 
EMaSr = r1Sr./Sr; EMaP = (r1P2O5.*10000.*0.4364)./P; EMaNd = r1Nd./Nd; EMaZr = r1Zr./Zr;
EMaSm = r1Sm./Sm; EMaEu = r1Eu./Eu;
EMaTi = (r1TiO2.*10000.*0.5993)./Ti; EMaDy = r1Dy./Dy; EMaY = r1Y./Y; EMaHo = r1Ho./Ho;
EMaYb = r1Yb./Yb; EMaLu = r1Lu./Lu;
EManorm = [EMaCs EMaRb EMaBa EMaTh EMaU EMaNb EMaTa EMaK EMaLa EMaCe EMaPb EMaPr EMaSr EMaP EMaNd EMaZr EMaSm EMaEu EMaTi EMaDy EMaY EMaHo EMaYb EMaLu];
clear EMaCs EMaRb EMaBa EMaTh EMaU EMaNb EMaTa EMaK EMaLa EMaCe EMaPb EMaPr EMaSr EMaP EMaNd EMaZr EMaSm EMaEu EMaTi EMaDy EMaY EMaHo EMaYb EMaLu
EMbCs = r2Cs./Cs; EMbRb = r2Rb./Rb; EMbBa = r2Ba./Ba; EMbTh = r2Th./Th;
EMbU  = r2U./U;   EMbNb = r2Nb./Nb; 
EMbTa = r2Ta./Ta; EMbK  = (r2K2O.*10000.*0.8301)./K; EMbLa = r2La./La; EMbCe = r2Ce./Ce;
EMbPb = r2Pb./Pb; EMbPr = r2Pr./Pr; 
EMbSr = r2Sr./Sr; EMbP = (r2P2O5.*10000.*0.4364)./P; EMbNd = r2Nd./Nd; EMbZr = r2Zr./Zr;
EMbSm = r2Sm./Sm; EMbEu = r2Eu./Eu;
EMbTi = (r2TiO2.*10000.*0.5993)./Ti; EMbDy = r2Dy./Dy; EMbY = r2Y./Y; EMbHo = r2Ho./Ho;
EMbYb = r2Yb./Yb; EMbLu = r2Lu./Lu;
EMbnorm = [EMbCs EMbRb EMbBa EMbTh EMbU EMbNb EMbTa EMbK EMbLa EMbCe EMbPb EMbPr EMbSr EMbP EMbNd EMbZr EMbSm EMbEu EMbTi EMbDy EMbY EMbHo EMbYb EMbLu];
clear EMbCs EMbRb EMbBa EMbTh EMbU EMbNb EMbTa EMbK EMbLa EMbCe EMbPb EMbPr EMbSr EMbP EMbNd EMbZr EMbSm EMbEu EMbTi EMbDy EMbY EMbHo EMbYb EMbLu
EMcCs = r3Cs./Cs; EMcRb = r3Rb./Rb; EMcBa = r3Ba./Ba; EMcTh = r3Th./Th;
EMcU  = r3U./U;   EMcNb = r3Nb./Nb; 
EMcTa = r3Ta./Ta; EMcK  = (r3K2O.*10000.*0.8301)./K; EMcLa = r3La./La; EMcCe = r3Ce./Ce;
EMcPb = r3Pb./Pb; EMcPr = r3Pr./Pr; 
EMcSr = r3Sr./Sr; EMcP = (r3P2O5.*10000.*0.4364)./P; EMcNd = r3Nd./Nd; EMcZr = r3Zr./Zr;
EMcSm = r3Sm./Sm; EMcEu = r3Eu./Eu;
EMcTi = (r3TiO2.*10000.*0.5993)./Ti; EMcDy = r3Dy./Dy; EMcY = r3Y./Y; EMcHo = r3Ho./Ho;
EMcYb = r3Yb./Yb; EMcLu = r3Lu./Lu;
EMcnorm = [EMcCs EMcRb EMcBa EMcTh EMcU EMcNb EMcTa EMcK EMcLa EMcCe EMcPb EMcPr EMcSr EMcP EMcNd EMcZr EMcSm EMcEu EMcTi EMcDy EMcY EMcHo EMcYb EMcLu];
clear EMcCs EMcRb EMcBa EMcTh EMcU EMcNb EMcTa EMcK EMcLa EMcCe EMcPb EMcPr EMcSr EMcP EMcNd EMcZr EMcSm EMcEu EMcTi EMcDy EMcY EMcHo EMcYb EMcLu
% Create x-axis
xax2    = [1:24];
spitext = {'Cs' 'Rb' 'Ba' 'Th' 'U' 'Nb' 'Ta' 'K' 'La' 'Ce' 'Pb' 'Pr' 'Sr' 'P' 'Nd' 'Zr' 'Sm' 'Eu' 'Ti' 'Dy' 'Y' 'Ho' 'Yb' 'Lu'};
clear Cs Rb Ba Th U Nb Ta K La Ce Pb Pr Sr P Nd Zr Sm Eu Ti Dy Y Ho Yb Lu
% Create the figure
    EMORBspi4 = figure('Visible','on','Position',[130,130,900,800]);
    set(EMORBspi4,'Name','Spider plots (E-type MORB normalized) - FastGAPP v1.0 - 3 datasets')
semilogy(xax2,EMcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')
                hold all
semilogy(xax2,EMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax2,EManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 24.25 0.1 1000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1:1:24],...
          'XTickLabel',spitext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('Spider plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / EMORB','fontsize',12,'fontweight','b')     
% Clear data
clear xax2 spitext
clear EManorm  EMbnorm EMcnorm EMORBspi4

%% OIB normalization
% OIB normalization values
Cs = 0.387;  Rb = 31.0;   Ba = 350;   Th = 4.00;  U = 1.02;  Nb = 48.0;
Ta = 2.70;  K  = 12000;    La = 37.0;  Ce = 80.0;  Pb = 3.20;   Pr = 9.70;  
Sr = 660;   P = 2700;    Nd = 38.5;  Zr = 280;   Sm = 10.0;  Eu = 3.00;  
Ti = 17200;    Dy = 5.600; Y  = 29;   Ho = 1.06; Yb = 2.16; Lu = 0.300;
% Normalization
OIBaCs = r1Cs./Cs; OIBaRb = r1Rb./Rb; OIBaBa = r1Ba./Ba; OIBaTh = r1Th./Th;
OIBaU  = r1U./U;   OIBaNb = r1Nb./Nb; 
OIBaTa = r1Ta./Ta; OIBaK  = (r1K2O.*10000.*0.8301)./K; OIBaLa = r1La./La; OIBaCe = r1Ce./Ce;
OIBaPb = r1Pb./Pb; OIBaPr = r1Pr./Pr; 
OIBaSr = r1Sr./Sr; OIBaP = (r1P2O5.*10000.*0.4364)./P; OIBaNd = r1Nd./Nd; OIBaZr = r1Zr./Zr;
OIBaSm = r1Sm./Sm; OIBaEu = r1Eu./Eu;
OIBaTi = (r1TiO2.*10000.*0.5993)./Ti; OIBaDy = r1Dy./Dy; OIBaY = r1Y./Y; OIBaHo = r1Ho./Ho;
OIBaYb = r1Yb./Yb; OIBaLu = r1Lu./Lu;
OIBanorm = [OIBaCs OIBaRb OIBaBa OIBaTh OIBaU OIBaNb OIBaTa OIBaK OIBaLa OIBaCe OIBaPb OIBaPr OIBaSr OIBaP OIBaNd OIBaZr OIBaSm OIBaEu OIBaTi OIBaDy OIBaY OIBaHo OIBaYb OIBaLu];
clear OIBaCs OIBaRb OIBaBa OIBaTh OIBaU OIBaNb OIBaTa OIBaK OIBaLa OIBaCe OIBaPb OIBaPr OIBaSr OIBaP OIBaNd OIBaZr OIBaSm OIBaEu OIBaTi OIBaDy OIBaY OIBaHo OIBaYb OIBaLu
OIBbCs = r2Cs./Cs; OIBbRb = r2Rb./Rb; OIBbBa = r2Ba./Ba; OIBbTh = r2Th./Th;
OIBbU  = r2U./U;   OIBbNb = r2Nb./Nb; 
OIBbTa = r2Ta./Ta; OIBbK  = (r2K2O.*10000.*0.8301)./K; OIBbLa = r2La./La; OIBbCe = r2Ce./Ce;
OIBbPb = r2Pb./Pb; OIBbPr = r2Pr./Pr; 
OIBbSr = r2Sr./Sr; OIBbP = (r2P2O5.*10000.*0.4364)./P; OIBbNd = r2Nd./Nd; OIBbZr = r2Zr./Zr;
OIBbSm = r2Sm./Sm; OIBbEu = r2Eu./Eu;
OIBbTi = (r2TiO2.*10000.*0.5993)./Ti; OIBbDy = r2Dy./Dy; OIBbY = r2Y./Y; OIBbHo = r2Ho./Ho;
OIBbYb = r2Yb./Yb; OIBbLu = r2Lu./Lu;
OIBbnorm = [OIBbCs OIBbRb OIBbBa OIBbTh OIBbU OIBbNb OIBbTa OIBbK OIBbLa OIBbCe OIBbPb OIBbPr OIBbSr OIBbP OIBbNd OIBbZr OIBbSm OIBbEu OIBbTi OIBbDy OIBbY OIBbHo OIBbYb OIBbLu];
clear OIBbCs OIBbRb OIBbBa OIBbTh OIBbU OIBbNb OIBbTa OIBbK OIBbLa OIBbCe OIBbPb OIBbPr OIBbSr OIBbP OIBbNd OIBbZr OIBbSm OIBbEu OIBbTi OIBbDy OIBbY OIBbHo OIBbYb OIBbLu
OIBcCs = r3Cs./Cs; OIBcRb = r3Rb./Rb; OIBcBa = r3Ba./Ba; OIBcTh = r3Th./Th;
OIBcU  = r3U./U;   OIBcNb = r3Nb./Nb; 
OIBcTa = r3Ta./Ta; OIBcK  = (r3K2O.*10000.*0.8301)./K; OIBcLa = r3La./La; OIBcCe = r3Ce./Ce;
OIBcPb = r3Pb./Pb; OIBcPr = r3Pr./Pr; 
OIBcSr = r3Sr./Sr; OIBcP = (r3P2O5.*10000.*0.4364)./P; OIBcNd = r3Nd./Nd; OIBcZr = r3Zr./Zr;
OIBcSm = r3Sm./Sm; OIBcEu = r3Eu./Eu;
OIBcTi = (r3TiO2.*10000.*0.5993)./Ti; OIBcDy = r3Dy./Dy; OIBcY = r3Y./Y; OIBcHo = r3Ho./Ho;
OIBcYb = r3Yb./Yb; OIBcLu = r3Lu./Lu;
OIBcnorm = [OIBcCs OIBcRb OIBcBa OIBcTh OIBcU OIBcNb OIBcTa OIBcK OIBcLa OIBcCe OIBcPb OIBcPr OIBcSr OIBcP OIBcNd OIBcZr OIBcSm OIBcEu OIBcTi OIBcDy OIBcY OIBcHo OIBcYb OIBcLu];
clear OIBcCs OIBcRb OIBcBa OIBcTh OIBcU OIBcNb OIBcTa OIBcK OIBcLa OIBcCe OIBcPb OIBcPr OIBcSr OIBcP OIBcNd OIBcZr OIBcSm OIBcEu OIBcTi OIBcDy OIBcY OIBcHo OIBcYb OIBcLu
% Create x-axis
xax2    = [1:24];
spitext = {'Cs' 'Rb' 'Ba' 'Th' 'U' 'Nb' 'Ta' 'K' 'La' 'Ce' 'Pb' 'Pr' 'Sr' 'P' 'Nd' 'Zr' 'Sm' 'Eu' 'Ti' 'Dy' 'Y' 'Ho' 'Yb' 'Lu'};
clear Cs Rb Ba Th U Nb Ta K La Ce Pb Pr Sr P Nd Zr Sm Eu Ti Dy Y Ho Yb Lu
% Create the figure
    OIBspi4 = figure('Visible','on','Position',[140,140,900,800]);
    set(OIBspi4,'Name','Spider plots (OIB normalized) - FastGAPP v1.0 - 3 datasets')
semilogy(xax2,OIBcnorm,'LineStyle','-','Color','g','LineWidth',[2],'Marker','v',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','g')      
                hold all
semilogy(xax2,OIBbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
semilogy(xax2,OIBanorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')  
                hold off
          axis ([0.75 24.25 0.01 100])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1:1:24],...
          'XTickLabel',spitext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('Spider plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / OIB','fontsize',12,'fontweight','b')
% Clear data
clear xax2 spitext
clear OIBanorm OIBbnorm OIBcnorm OIBspi4