% Geochemical discrimination using trace elements for a single dataset
% Identification and geochemical discrimination of magmatic series using
% immobile elements diagrams (SiO2 vs Zr/TiO2, SiO2 vs. Nb/Y, and
% Zr/TiO2 vs. Nb/Y after Winchester & Floyd (1977)
%
% Reference:
% J.A. Winchester and P.A. Floyd (1977). Geochemical discrimination of different
% magma series and their differentiation products using immobile elements 
% - Chemical Geology 21, 291-306.

%% Run normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)
    
%% Calculation
n1ZrdivTiO2 = n1Zr./(n1TiO2.*10000);
n1NbdivY    = n1Nb./n1Y;
    
%% SiO2 vs. Zr/TiO2 diagram
wf11 = figure('Visible','on','Position',[200,100,900,750]);
      set(wf11,'Name','Winchester & Floyd (1977) discrimination - FGAPP v1.0 - 1 dataset')
semilogx([0.0022 0.0145 0.032 0.155],[53 53 53.2 48.5],'k-',...
         [0.032 0.0095],[53.2 44.5],'k-',[0.0145 0.038 0.56],[53 62.5 78],'k-',...
         [0.00056 0.02 0.035 0.038 0.045 0.05 0.055 0.06 0.065 0.07 0.075 0.08 0.085 0.09 0.094],...
         [63 63 62.75 62.5 62.25 62 61.75 61.5 61.25 61 60.75 60.5 60.25 60 59.75],'k-',...
         [0.021 0.03 0.04 0.06 0.094 0.11 1.9],[53.1 55 56.4 58.1 59.75 60.05 62],'k-',...
         [0.01 0.239],[73 73.1],'k-',[0.0785 1.3],[66.6 66.7],'k-',...
         [0.0175 0.009],[53 47.3],'k--','LineWidth',2)
    text(0.08,76,'Rhyolite','fontsize',10,'fontweight','b')
    text(0.2,69,'Comendite/Pantellerite','fontsize',10,'fontweight','b')
    text(0.02,68,'Rhyodacite/Dacite','fontsize',10,'fontweight','b')
    text(0.2,63,'Trachyte','fontsize',10,'fontweight','b')
    text(0.005,58,'Andesite','fontsize',10,'fontweight','b')
    text(0.038,60,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
    text(0.15,56,'Phonolite','fontsize',10,'fontweight','b')
    text(0.004,50,sprintf('Subalkaline\nBasalt'),'fontsize',10,'fontweight','b')
    text(0.016,51.5,sprintf('Alkaline\nBasalt'),'fontsize',8,'fontweight','b')
    text(0.03,49,sprintf('Basanite\nTrachybasanite\nNephelinite'),'fontsize',10,'fontweight','b')
    hold all
semilogx(n1ZrdivTiO2,n1SiO2,'rs','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([0.001 1 40 80])
    set(gca,'YTick',40:5:80,'XTickLabel',[0.001 0.01 0.1 1],'FontWeight','b','LineWidth',2)
    title('SiO_2 vs. Zr/TiO_2 (after Winchester & Floyd, 1977)','fontsize',12,'fontweight','b')
    xlabel('Zr/TiO_2','fontsize',12,'fontweight','b')
    ylabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')

%% SiO2 vs. Nb/Y diagram
wf21 = figure('Visible','on','Position',[220,120,900,750]);
      set(wf21,'Name','Winchester & Floyd (1977) discrimination - FGAPP v1.0 - 1 dataset')
semilogx([0.018 4.25 3.1 2.55 1.35],[53 53 47 45 42.5],'k-',...
         [0.68 0.68 0.7 0.74 0.078],[45 62.5 66 72.8 72.8],'k-',...
         [0.74 1.1 1.5],[72.8 75.5 77],'k-',[0.7 10],[66 66],'k-',...
         [1.55 10],[59.7 59.7],'k-',[0.034 0.3 0.68 1.55 2.1 3.75 4.25],...
         [62.9 62.7 62.2 59.7 58.2 54.55 53],'k-',[4.25 7.4],[53 50.9],'k--',...
         'LineWidth',2)
    text(0.5,76,'Rhyolite','fontsize',10,'fontweight','b')
    text(1.2,69,'Comendite/Pantellerite','fontsize',10,'fontweight','b')
    text(0.1,68,'Rhyodacite/Dacite','fontsize',10,'fontweight','b')
    text(1.1,63,'Trachyte','fontsize',10,'fontweight','b')
    text(0.15,58,'Andesite','fontsize',10,'fontweight','b')
    text(0.9,57,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
    text(4,56,'Phonolite','fontsize',10,'fontweight','b')
    text(0.15,50,'Subalkaline Basalt','fontsize',10,'fontweight','b')
    text(1.4,51,sprintf('Alkaline\nBasalt'),'fontsize',10,'fontweight','b')
    text(4,48,sprintf('Basanite\nNephelinite'),'fontsize',10,'fontweight','b')
    hold all
semilogx(n1NbdivY,n1SiO2,'rs','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([0.01 10 40 80])
    set(gca,'YTick',40:4:76,'XTickLabel',[0.01 0.1 1 10],'FontWeight','b','LineWidth',2)
    title('SiO_2 vs. Nb/Y (after Winchester & Floyd, 1977)','fontsize',12,'fontweight','b')
    xlabel('Nb/Y','fontsize',12,'fontweight','b')
    ylabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')


%% Zr/TiO2 vs. Nb/Y
wf31 = figure('Visible','on','Position',[240,140,900,750]);
      set(wf31,'Name','Winchester & Floyd (1977) discrimination - FGAPP v1.0 - 1 dataset')
loglog([0.029 0.205 0.3 0.4 0.5 0.6 0.8 1 1.4 2 3 3],...
       [0.0047 0.0053 0.0059 0.013 0.0155 0.0175 0.021 0.023 0.024 0.021 0.0155 0.005],'k-',...
       [0.5 0.4 0.3 0.2 0.1 0.06],[0.0155 0.0145 0.0132 0.012 0.0115 0.0112],'k-',...
       [0.67 0.67 0.2],[0.0027 0.085 0.12],'k-',...
       [0.022 0.3 0.35 0.4 0.5 0.6 0.67],[0.06 0.027 0.026 0.0255 0.0255 0.026 0.0265],'k-',...
       [0.67 0.94],[0.085 0.14],'k-',[3 4.35 5.6],[0.0155 0.024 0.04],'k-',...
       [0.34 0.94 1.25 5.6 10],[0.63 0.14 0.094 0.04 0.04],'k-',...
       [1.25 1.45 1.8],[0.094 0.14 1.4],'k-',...
       [10 9 8 7 6 5 4 3 2.4 2 1.8 1.6],[0.15 0.155 0.165 0.177 0.195 0.22 0.26 0.35 0.47 0.8 1.4 3],'k-',...
       'LineWidth',2)
    text(0.3,0.2,'Rhyolite','fontsize',10,'fontweight','b')
    text(0.5,1,sprintf('Comendite\nPantellerite'),'fontsize',10,'fontweight','b')
    text(0.09,0.07,'Rhyodacite/Dacite','fontsize',10,'fontweight','b')
    text(2,0.17,'Trachyte','fontsize',10,'fontweight','b')
    text(0.08,0.02,'Andesite','fontsize',10,'fontweight','b')
    text(1,0.04,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
    text(3,1.2,'Phonolite','fontsize',10,'fontweight','b')
    text(0.15,0.003,'Subalkaline Basalt','fontsize',10,'fontweight','b')
    text(1.2,0.005,sprintf('Alkaline\nBasalt'),'fontsize',10,'fontweight','b')
    text(0.1,0.008,sprintf('Andesite/\nBasalt'),'fontsize',10,'fontweight','b')
    text(4,0.007,sprintf('Basanite\nNephelinite'),'fontsize',10,'fontweight','b')
    hold all
loglog(n1NbdivY,n1ZrdivTiO2,'rs','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([0.01 10 0.001 5])
    set(gca,'XTickLabel',[0.01 0.1 1 10],'YTick',[0.001 0.01 0.1 1 5],...
    'YTickLabel',[0.001 0.01 0.1 1 5],'FontWeight','b','LineWidth',2)
    title('Zr/TiO_2 vs. Nb/Y (after Winchester & Floyd, 1977)','fontsize',12,'fontweight','b')
    xlabel('Nb/Y','fontsize',12,'fontweight','b')
    ylabel('Zr/TiO_2','fontsize',12,'fontweight','b')
    
    %% Clear data
clear wf11 wf21 wf31
clear n1ZrdivTiO2 n1NbdivY