%% Generate a geotectonic discrimination diagram using Ta, Th, and Hf after Wood (1980).
%
% Wood, D.A., 1980. The application of a ThHfTa diagram to problems of 
% tectonomagmatic classification and to establishing the nature of crustal 
% contamination of basaltic lavas of the British Tertiary Volcanic Province. 
% Earth and Planetary Science Letters 50, 11-30.
%
% Link: http://dx.doi.org/10.1016/0012-821X(80)90116-8

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)

%% Calculation
    a1sum = n1Ta+(n1Hf./3)+n1Th;
    a1Hf   = ((n1Hf./3)./a1sum)*sin(deg2rad(60));
    a1Ta   = (n1Ta./a1sum)+a1Hf*cot(deg2rad(60));

    a2sum = n2Ta+(n2Hf./3)+n2Th;
    a2Hf   = ((n2Hf./3)./a2sum)*sin(deg2rad(60));
    a2Ta   = (n2Ta./a2sum)+a2Hf*cot(deg2rad(60));

    a3sum = n3Ta+(n3Hf./3)+n3Th;
    a3Hf   = ((n3Hf./3)./a3sum)*sin(deg2rad(60));
    a3Ta   = (n3Ta./a3sum)+a3Hf*cot(deg2rad(60));

    a4sum = n4Ta+(n4Hf./3)+n4Th;
    a4Hf   = ((n4Hf./3)./a4sum)*sin(deg2rad(60));
    a4Ta   = (n4Ta./a4sum)+a4Hf*cot(deg2rad(60));

%% Create plot
Wood = figure('Visible','on','Position',[200,100,800,800]);
    movegui(Wood,'center')
    set(Wood,'Name','Wood (1980) - FGAPP v1.0 - 4 datasets')
% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundaries
    plot([0.050 0.313 0.452 0.464 0.425],...
        [0.000 0.210 0.598 0.673 0.736],...
        [0.530 0.464 0.452 0.417 0.606 0.530],...
        [0.762 0.673 0.598 0.395 0.569 0.762],...
        [0.675 0.606 0.417 0.326 0.325 0.568 0.661 0.675],...
        [0.476 0.569 0.395 0.213 0.169 0.291 0.369 0.476],...
        [0.325 0.568 0.577 0.538 0.327 0.325],...
        [0.169 0.291 0.173 0.104 0.067 0.169],...
        'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.588 0.424],[0.613 0.434],...
        [0.641 0.404],[0.525 0.369],...
        [0.327 0.567],[0.156 0.274],...
        [0.328 0.661],[0.184 0.369],...
        [0.369 0.250],[0.364 0.433],...
        'Marker','none','Color','k','LineStyle','--','LineWidth',[2])
    text(0.525,0.6 ,'A','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.5,0.35,'B','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.45,0.15,'C','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.1,0.1,'D','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.60,0.82,...
    sprintf('A - N-type MORB\nB - E-type MORB and tholeitic within-plate basalts*\nC - Alkaline within-plate basalts*\nD - Destructive plate-margin basalts*\n*and differentiates'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
% Plot data
plot(a4Ta,a4Hf,'Marker','^','MarkerFaceColor','y','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a3Ta,a3Hf,'Marker','v','MarkerFaceColor','g','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a2Ta,a2Hf,'Marker','o','MarkerFaceColor','b','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a1Ta,a1Hf,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(1,-0.02,'Ta','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0,-0.02,'Th','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'Hf/3','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
title('Ta/Th/Hf diagram (after Wood, 1980)','FontSize',12,'FontWeight','b')
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear Wood
clear a1sum a1Hf a1Ta
clear a2sum a2Hf a2Ta
clear a3sum a3Hf a3Ta
clear a4sum a4Hf a4Ta