%% Generate Mafic - diagram

%% Opens dialog box for single input-file
[input_file1, input_path1] = uigetfile({'*.xlsx';'*.xls';'*.*'},...
                                        'Select Excel-Spreadsheet - Petro Plot v1.0');
                     
%% Reads data of the file into MATLAB-Workspace
    tic
    Status = 'Reading data...'
    Date  = datestr(clock)
    input_path_file1 = [input_path1 input_file1];
[input_dat1, ~,input_raw1] = xlsread(input_path_file1);
    Status = '...finished reading!'
    Date  = datestr(clock)
    toc

%% Runs normalization
    Ol = input_dat1(:,1);
    Cpx = input_dat1(:,2);
    Opx = input_dat1(:,3);

%% Calculation
    ultsum = Ol+Cpx+Opx;
    nOl   = (Ol./ultsum)*sin(deg2rad(60));
    nCpx   = (Cpx./ultsum)+nOl*cot(deg2rad(60));

%% Create plot
ult = figure('Visible','on','Position',[200,100,800,750]);
    movegui(ult,'center')
    set(ult,'Name','Classification of peridotites - Petro Plot v1.0')

%% Construct a ternary plot
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w','FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
% Plot boundaries
    plot([0.450 0.550],[0.779 0.779],[0.8 0.200],[0.346 0.346],...
         [0.925 0.075 0.500 0.925],[0.043 0.043 0.779 0.043],...
         [0.050 0.100],[0.087 0.000],[0.900 0.950],[0.000 0.087],...
    'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.8 1],[0.346 0.346],'Marker','none','Color','k','LineStyle','--','LineWidth',[2])
% Plot labels
    text(0.9,0.366,'Peridotites','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
    text(0.9,0.326,'Pyroxenites','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
    text(0.5,0.795,'Dunite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.5,0.5,'Lherzolite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
    text(0.278,0.45,'Harzburgite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',60);
    text(0.722,0.45,'Wehrlite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',-60);
    text(0.5,0.2,'Olivine websterite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
    text(0.5,0.02,'Websterite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
% Plot lines and labels
    line([0.04 0],[0.05 0.08],'Color',[0.2 0.2 0.2],'LineStyle','-','LineWidth',[2])
    text(-0.06,0.1,sprintf('Ortho-\npyroxenite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
    line([0.96 1],[0.05 0.08],'Color',[0.2 0.2 0.2],'LineStyle','-','LineWidth',[2])
    text(1.06,0.1,sprintf('Clino-\npyroxenite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',10,'FontWeight','b');
% Plot data
plot(nCpx,nOl,'Marker','s','MarkerFaceColor',[1,0.5,0],'MarkerEdgeColor','k',...
    'MarkerSize',[5],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(0.5,0.95,'IUGS classification of ultramafic rocks','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(1.05,0,'Cpx','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(-0.05,0,'Opx','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.89,'Ol','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off; axis ([0 1 0 sin(1/3*pi)])

%% Clear data
clear ult ultsum nCpx nOl Ol Opx Cpx
clear Status Date
clear input_path1 input_pp1