%% Generate geotectonic discrimination diagram after Mullen (1983).
%
% Reference: Mullen, E.D., 1983. MnO/TiO2/P2O5: a minor element discriminant
% for basaltic rocks of oceanic environments and its implications for 
% petrogenesis. Earth and Planetary Science Letters 62, 53-62.
%
% Link: http://dx.doi.org/10.1016/0012-821X(83)90070-5

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    normalization4
    cd(folder_plot)

% Calculation
    a1sum = (n1P2O5.*10)+(n1MnO.*10)+n1TiO2;
    a1T   = ((n1TiO2)./a1sum)*sin(deg2rad(60));
    a1P   = ((n1P2O5.*10)./a1sum)+a1T*cot(deg2rad(60));

    a2sum = (n2P2O5.*10)+(n2MnO.*10)+n2TiO2;
    a2T   = ((n2TiO2)./a2sum)*sin(deg2rad(60));
    a2P   = ((n2P2O5.*10)./a2sum)+a2T*cot(deg2rad(60));
    
    a3sum = (n3P2O5.*10)+(n3MnO.*10)+n3TiO2;
    a3T   = ((n3TiO2)./a3sum)*sin(deg2rad(60));
    a3P   = ((n3P2O5.*10)./a3sum)+a3T*cot(deg2rad(60));
    
    a4sum = (n4P2O5.*10)+(n4MnO.*10)+n4TiO2;
    a4T   = ((n4TiO2)./a4sum)*sin(deg2rad(60));
    a4P   = ((n4P2O5.*10)./a4sum)+a4T*cot(deg2rad(60));

%% Create plot
Mullen = figure('Visible','on','Position',[200,100,800,800]);
    movegui(Mullen,'center')
    set(Mullen,'Name','Mullen (1983) - FGAPP v1.0 - 4 datasets')
% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundaries
    plot([0.920 0.557 0.412],[0.000 0.256 0.594],...
         [0.295 0.459 0.592],[0.511 0.230 0.230],...
        'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.557 0.729],[0.256 0.365],...
         [0.195 0.300 0.693],[0.338 0.155 0.155],...
        'Marker','none','Color','k','LineStyle','--','LineWidth',[2])
    text(0.6,0.5,'OIT','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.75,0.2,'OIA','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.425,0.4,'MORB','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.35,0.25,'IAT','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.4,0.1,'CAB','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.65,0.8,...
    sprintf('OIT - oceanic island tholeiite\nOIA - oceanic island alkaline basalt\nMORB - mid-ocean reidge basalt\nIAT - island arc tholeiite\nCAB - calc-alkaline basalt'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
    title('MnO/TiO_2/P_2O_5 diagram (after Mullen, 1983)','FontSize',12,'FontWeight','b')
% Plot data
plot(a4P,a4T,'Marker','^','MarkerFaceColor','y','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a3P,a3T,'Marker','v','MarkerFaceColor','g','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a2P,a2T,'Marker','o','MarkerFaceColor','b','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a1P,a1T,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(1,-0.05,'10 P_2O_5','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.05,-0.0425,'10 MnO','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'TiO_2','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear Mullen
clear a1sum a1P a1T
clear a2sum a2P a2T 
clear a3sum a3P a3T
clear a4sum a4P a4T