%% Generate QAPF - diagram

%% Opens dialog box for single input-file
[input_file1, input_path1] = uigetfile({'*.xlsx';'*.xls';'*.*'},...
                                        'Select Excel-Spreadsheet - Petro Plot v1.0');
                     
%% Reads data of the file into MATLAB-Workspace
    tic
    Status = 'Reading data...'
    Date  = datestr(clock)
    input_path_file1 = [input_path1 input_file1];
[~, ~,input_raw1] = xlsread(input_path_file1);
    Status = '...finished reading!'
    Date  = datestr(clock)
    toc

%% Split data
    [h ~] = size(input_raw1);
    Q = input_raw1(3:h,2); Q = cell2mat(Q);
    A = input_raw1(3:h,3); A = cell2mat(A);
    P = input_raw1(3:h,4); P = cell2mat(P);
    F = input_raw1(3:h,5); F = cell2mat(F);
    clear h

%% Calculation
    qapsum = Q+A+P;
    nQ   = (Q./qapsum)*sin(deg2rad(60));
    n1P   = (P./qapsum)+nQ*cot(deg2rad(60));
    
    fapsum = F+A+P;
    nF   = (F./fapsum)*sin(deg2rad(60));
    n2P   = (P./fapsum)+nF*cot(deg2rad(60)); 
    nF = -nF;
    
%% Create plot
qapf = figure('Visible','on','Position',[200,100,700,900]);
    movegui(qapf,'center')
    set(qapf,'Name','Volcanic QAPF diagram - Petro Plot v1.0')

%% Construct a ternary plot
    patch('Xdata',[0 0.5 1 0.5 0],'Ydata',[0 -sin(1/3*pi) 0 sin(1/3*pi) 0],'EdgeColor','w','FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 0.5 1 0.5 0],[0 -sin(1/3*pi) 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
% Plot horizontal boundaries
    plot([0.450 0.550],[-0.779 -0.779],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0 0.65],[0 0],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.450 0.550],[0.779 0.779],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.300 0.700],[0.520 0.520],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.300 0.700],[-0.520 -0.520],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.050 0.950],[-0.087 -0.087],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.025 0.643],[0.043 0.043],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.9 0.1],[0.173 0.173],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
% Plot vertical boundaries    
    plot([0.5 0.5],[-0.087 -0.779],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.340 0.1 0.340],[0.520 0 -0.520],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.860 0.660],[-0.087 -0.520],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.380 0.35 0.365],[0.173 0 -0.087],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.620 0.65 0.635],[0.173 0 -0.087],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.620 0.560],[0.173 0.520],'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    plot([0.380 0.440],[0.173 0.520],'Marker','none','Color','k','LineStyle','--','LineWidth',[2])
    plot([0.660 0.820],[0.520 0.173],'Marker','none','Color','k','LineStyle','--','LineWidth',[2])
% Plot labels
    text(0.41,0.35,'Rhyolite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b','Margin',1,'BackgroundColor','w');
    text(0.71,0.35,'Dacite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b','Margin',1,'BackgroundColor','w');
    text(0.256,0.10,sprintf('Quartz\ntrachyte'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b','Margin',1,'BackgroundColor','w');
    text(0.5,0.10,sprintf('Quartz\nlatite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b','Margin',1,'BackgroundColor','w');
    text(0.23,0.35,'Alkali feldspar rhyolite','HorizontalAlignment','center','rotation',60,...
    'VerticalAlignment','middle','FontSize',7,'FontWeight','b');
    text(0.256,0.022,'Trachyte','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.5,0.022,'Latite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.74,0.045,sprintf('Basalt\nAndesite'),'fontsize',9,'fontweight','b')
    text(0.256,-0.05,sprintf('Foid-bearing\ntrachyte'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.5,-0.05,sprintf('Foid-bearing\nLatite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.38,-0.25,sprintf('Tephritic\nphonolite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.65,-0.25,sprintf('Phonolitic basanite\nPhonolitic tephrite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.175,-0.25,'Phonolite','HorizontalAlignment','center','rotation',-60,...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.832,-0.25,'Tephrite / Basanite','HorizontalAlignment','center','rotation',60,...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.43,-0.63,sprintf('Tephritic\nfoidite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
    text(0.575,-0.63,sprintf('Phonolitic\nfoidite'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
% Plot labels with lines
    line([-0.2 0.075],[0.1 0.025],'Color','k','LineWidth',[2])
    text(-0.12,0.075,sprintf('Alkali\nfeldspar trachyte'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');    
    line([-0.2 0.075],[-0.1 -0.05],'Color','k','LineWidth',[2])
    text(-0.12,-0.075,sprintf('Foid-bearing alkali\nfeldspar trachyte'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');  
    line([-0.2 0.075],[0.22 0.075],'Color','k','LineWidth',[2])
    text(-0.10,0.15,sprintf('Quartz alkali\nfeldspar trachyte'),'HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');   
    line([0.5 0.4],[-0.82 -0.82],'Color','k','LineWidth',[2])
    text(0.35,-0.82,'Foidite','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',8,'FontWeight','b');
% Plot data
plot(n1P,nQ,'Marker','s','MarkerFaceColor',[1,0.5,0],'MarkerEdgeColor','k',...
    'MarkerSize',[5],'LineStyle','none','LineWidth',[1])
plot(n2P,nF,'Marker','s','MarkerFaceColor',[1,0.5,0],'MarkerEdgeColor','k',...
    'MarkerSize',[5],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(0.5,0.95,'IUGS classification of volcanic rocks','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(1.05,0,'P','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,-0.9,'F','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(-0.05,0,'A','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.89,'Q','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off; axis ([0 1 -sin(1/3*pi) sin(1/3*pi)])

%% Clear data
clear qapf qapsum fapsum nQ n1P nF n2P Q A P F
clear Status Date
clear input_path1 input_pp1