% Generates the log Th vs. Co diagram to classify altered subduction-related 
% igneous rocks from island arcs Hastie et al. (2007).
%
% Reference:
%
% Hastie, A.R., Kerr, A.C., Pearce, J.A., Mitchell, S.F., 2007. Classification 
% of altered volcanic island arc rocks using immobiletrace elements: development 
% of the Th-Co discrimination diagram. Journal of Petrology 48, 2341-2357.
%
% Link: doi:10.1093/petrology/egm062

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    cd(folder_plot)

    %% K2O vs. Na2O
% K2O vs. Na2O diagram
has1 = figure('Visible','on','Position',[200,100,910,800]);
    movegui(has1,'center')
    set(has1,'Name','K2O vs. Na2O diagram - FGAPP v1.0 - 3 datasets')
% Generate the division line
semilogy([38.4 24],[0.01 100],'k-','LineWidth',2)
   hold all
plot([23 7],[0.01 100],'k-','LineWidth',2)
plot([70 0],[0.245 1.35],'k-','LineWidth',2)
plot([70 0],[2.2 9],'k-','LineWidth',2)
    text(20,0.015,sprintf('Dacite/\nRhyolite'),'fontsize',12,'fontweight','b','Rotation',0)
    text(36,0.015,sprintf('Andesite/\nBasaltic Andesite'),'fontsize',12,'fontweight','b','Rotation',0)
    text(44,0.015,'Basalt','fontsize',12,'fontweight','b','Rotation',0)
    text(68,0.175,sprintf('Island Arc Tholeiite'),'fontsize',12,'fontweight','b','Rotation',0)
    text(68,0.83,'Calc-Alkaline','fontsize',12,'fontweight','b','Rotation',0)
    text(68,4,sprintf('High-K Calc-Alkaline/\nShoshonite'),'fontsize',12,'fontweight','b','Rotation',0)
plot(n3Na2O,n3K2O,'v','MarkerEdgeColor','k',...
                    'MarkerFaceColor','g',...
                    'MarkerSize',6)
plot(n2Na2O,n2K2O,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1Na2O,n1K2O,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([0 70 0.01 100])
set(gca,'XTick',0:10:70,'XDir','reverse','FontWeight','bold','YTick',[0.01 0.1 1 10 100],...
        'YTickLabel',[0.01 0.1 1 10 100],'LineWidth',2)
title('Th vs. Co classification diagram (Hastie et al., 2007)','fontsize',12,'fontweight','b')
xlabel('Co [ppm]','fontsize',12,'fontweight','b')
ylabel('Th [ppm]','fontsize',12,'fontweight','b')

%% Clear data
clear has1