%% Generate Zr vs Ti, Ti/100-Zr-3Y ternary and Ti/100-Zr-Sr/2 ternary geotectonic 
% discrimination diagram with fields from Pearce & Cann (1973)
%
% Reference: Pearce, J.A., Cann, J.R., 1973. Tectonic setting of basic volcanic 
% rocks determined using trace element analyses. Earth and Planetary Science 
% Letters 19, 290-300.
%
% Link: doi:10.1016/0012-821x(73)90129-5

% Runs normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

% Create data Zr vs. Ti
a1Ti = n1TiO2.*0.5993.*10000;

    pearcecann1 = figure('Visible','on','Position',[200,50,750,600]);
      movegui(pearcecann1,'center')
      set(pearcecann1,'Name','Pearce & Cann (1973) - FGAPP v1.0 - 1 dataset')
plot([12.5 65 65 40 30 43 60 50 17.5 12.5],[1750 2300 5000 3000 4000 6100 7600 8500 4500 1750],...
     [77.5 65 40 30 43 60 77.5],[6200 5000 3000 4000 6100 7600 6200],...
     [65 65 77.5 90 133 192 189 110 65],[2300 5000 6200 7250 7100 6450 3500 2500 2300],...
     [77.5 90 133 165 130 85 60 77.5],[6200 7250 7100 11000 13250 10250 7600 6200],...
    'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    hold all
plot(n1Zr,a1Ti,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    text(25,3000,'A','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(55,5800,'B','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(125,4500,'C','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(125,10000,'D','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(5,13500,...
    sprintf('A+B - low-potassium tholeiites\nB+C - calc-alkali basalts\nB+D - ocean-floor basalts'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
    axis ([0 200 0 15000])
    set(gca,'LineWidth',2,'FontWeight','b')
    title('Ti vs. Zr (after Pearce & Cann, 1973)','fontsize',12,'fontweight','b')
    xlabel('Zr [ppm]','fontsize',12,'fontweight','b')
    ylabel('Ti [ppm]','fontsize',12,'fontweight','b')
    
%% Create data Ti-Sr-Zr
    a1sum = (n1TiO2.*100.*0.5993)+(n1Sr./2)+n1Zr;
    a1Ti   = ((n1TiO2.*100.*0.5993)./a1sum)*sin(deg2rad(60));
    a1Sr   = ((n1Sr./2)./a1sum)+a1Ti*cot(deg2rad(60));

%% Create plot
pearcecann2 = figure('Visible','on','Position',[200,150,800,800]);
    movegui(pearcecann2,'center')
    set(pearcecann2,'Name','Pearce & Cann (1973) diagram - FGAPP v1.0 - 1 dataset')

% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor',[1 1 1],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundaries
    plot([0.453 0.354 0.308 0.361 0.526 0.574 0.533 0.453],...
         [0.392 0.348 0.274 0.216 0.216 0.274 0.353 0.392],...
         [0.361 0.526 0.714 0.821 0.430 0.361],[0.216 0.216 0.151 0.043 0.094 0.216],...
         [0.533 0.574 0.526 0.714 0.821 0.781 0.668 0.533],...
         [0.353 0.274 0.216 0.151 0.043 0.181 0.299 0.353],...
         'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.67,0.23,'A','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.54,0.135,'B','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.43,0.3,'C','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.65,0.8,...
    sprintf('A - low-potassium tholeiites\nB - calc-alkali basalts\nC - ocean-floor basalts'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
    title('Ti/Zr/Sr diagram (after Pearce & Cann, 1973)','fontsize',12,'fontweight','b')
% Plot data
plot(a1Sr,a1Ti,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(0,-0.05,'Zr','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(1,-0.05,'Sr/2','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'Ti/100','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off;
    
%% Create data Ti-Y-Zr
    a1sum = (n1TiO2.*100.*0.5993)+(n1Y.*3)+n1Zr;
    a1Ti   = ((n1TiO2.*100.*0.5993)./a1sum)*sin(deg2rad(60));
    a1Y   = ((n1Y.*3)./a1sum)+a1Ti*cot(deg2rad(60));

%% Create plot
pearcecann3 = figure('Visible','on','Position',[200,100,800,800]);
    movegui(pearcecann3,'center')
    set(pearcecann3,'Name','Pearce & Cann (1973) diagram - FGAPP v1.0 - 1 dataset')

% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor',[1 1 1],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundaries
    plot([0.500 0.526 0.375 0.279 0.332 0.415 0.500],[0.362 0.414 0.433 0.242 0.204 0.255 0.362],...
         [0.500 0.526 0.608 0.600 0.500 0.415],[0.362 0.414 0.340 0.244 0.362 0.255],...
         [0.415 0.332 0.307 0.343 0.407 0.518 0.415],[0.255 0.204 0.146 0.098 0.093 0.162 0.255],...
         [0.500 0.415 0.518 0.600 0.500],[0.362 0.255 0.162 0.244 0.362],...
         'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.56,0.34,'A','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.5,0.25,'B','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.4,0.17,'C','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.4,0.33,'D','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',16,'FontWeight','b');
    text(0.65,0.8,...
    sprintf('A+B - low-potassium tholeiites\nB - ocean-floor basalts\nB+C - calc-alkali basalts\nD - ocean island and continental basalts'),...
    'horizontalalignment','left','verticalalignment','middle','fontsize',10,'fontweight','b');
    title('Ti/Zr/Y diagram (after Pearce & Cann, 1973)','fontsize',12,'fontweight','b')
% Plot data
plot(a1Y,a1Ti,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(0,-0.05,'Zr','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(1,-0.05,'3Y','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'Ti/100','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear pearcecann1 pearcecann2 pearcecann3
clear a1sum a1Ti a1Y a1Sr