%% Generate an TiO2-P2O5-K2O diagram to discriminate between oceanic and non-
% oceanic environment after Pearce et al. (1975).
%
% Reference: Pearce, T.H., Gorman, B.E., Birkett, T.C., 1975. The TiO2K2OP2O5 
% diagram: A method of discriminating between oceanic and non-oceanic basalts. 
% Earth and Planetary Science Letters 24, 419-426.
%
% Link: doi:10.1016/0012-821x(75)90149-1

%% Runs normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

%% Calculation
    a1sum = n1P2O5+n1K2O+n1TiO2;
    a1T   = (n1TiO2./a1sum)*sin(deg2rad(60));
    a1P   = (n1P2O5./a1sum)+a1T*cot(deg2rad(60));

%% Create plot
Pet = figure('Visible','on','Position',[200,100,800,800]);
    movegui(Pet,'center')
    set(Pet,'Name','Pearce et al. (1975) - FGAPP v1.0 - 1 dataset')

%% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor','white','HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundary
    plot([0.600 0.270],...
         [0.693 0.468],...
        'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.5,0.7,'oceanic','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
    text(0.5,0.4,'non-oceanic','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
% Plot data
plot(a1P,a1T,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(1,-0.05,'P_2O_5','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0,-0.05,'K_2O','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'TiO_2','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
title('TiO_2/K_2O/P_2O_5 diagram (after Pearce et al., 1975)','FontSize',12,'FontWeight','b')
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear Pet
clear a1sum a1T a1P