%% Generate Al2O3-FeOtot-MgO ternary discrimination diagram with fields 
%  from Pearce et al. (1977)
%
% Reference: Pearce, T.H., Gorman, B.E., Birkett, T.C., 1977. The relationship 
% between major element chemistry and tectonic environment of basic and 
% intermediate volcanic rocks. Earth and Planetary Science Letters 36, 121-132.
%
% Link: doi:10.1016/0012-821x(77)90193-5

% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    normalization3
    cd(folder_plot)

% Create data
    a1sum = n1Al2O3+(0.8998.*n1Fe2O3)+n1MgO;
    a1F   = ((0.8998.*n1Fe2O3)./a1sum)*sin(deg2rad(60));
    a1Al   = (n1Al2O3./a1sum)+a1F*cot(deg2rad(60));

    a2sum = n2Al2O3+(0.8998.*n2Fe2O3)+n2MgO;
    a2F   = ((0.8998.*n2Fe2O3)./a2sum)*sin(deg2rad(60));
    a2Al   = (n2Al2O3./a2sum)+a2F*cot(deg2rad(60));

    a3sum = n3Al2O3+(0.8998.*n3Fe2O3)+n3MgO;
    a3F   = ((0.8998.*n3Fe2O3)./a3sum)*sin(deg2rad(60));
    a3Al   = (n3Al2O3./a3sum)+a3F*cot(deg2rad(60));

%% Create plot
pearceal4 = figure('Visible','on','Position',[200,100,800,800]);
    movegui(pearceal4,'center')
    set(pearceal4,'Name','Pearce et al. (1977) diagram - FGAPP v1.0 - 3 datasets')

%% Construct a ternary plot with tick marks (0.25 ranges)
    patch('Xdata',[0 1 0.5 0],'Ydata',[0 0 sin(1/3*pi) 0],'EdgeColor','w',...
                            'FaceColor',[1 1 1],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1])
    hold all
    plot ([0 1 0.5 0],[0 0 sin(1/3*pi) 0],'Color','k','LineWidth',[2],'HandleVisibility','off')
    set(gca, 'visible', 'off','dataaspectratio',[1 1 1]);
    plot([0.5 0.5],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.75 0.75],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.25 0.25],[0.000 0.017],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.750 0.735],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.625 0.611],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.875 0.861],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.250 0.265],[0.433 0.425],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.375 0.389],[0.650 0.641],'Color','k','LineWidth',[2],'HandleVisibility','off')
    plot([0.125 0.139],[0.217 0.208],'Color','k','LineWidth',[2],'HandleVisibility','off')
% Plot boundaries
    plot([0.489 0.626],[0.276 0.278],...
         [0.650 0.650 0.653 0.626 0.605],[0.098 0.180 0.240 0.278 0.453],...
         [0.653 0.663 0.688 0.714 0.735 0.765 0.800],...
         [0.240 0.286 0.300 0.280 0.255 0.221 0.173],...
         [0.688 0.690 0.676 0.662],[0.300 0.345 0.419 0.454],...
         'Marker','none','Color','k','LineStyle','-','LineWidth',[2])
    text(0.65,0.4,'CONTINENTAL','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',-80);
    text(0.55,0.35,'OCEAN ISLAND','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',-45);
    text(0.56,0.18,sprintf('OCEAN RIDGE \n AND FLOOR'),'HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',45);
    text(0.7,0.22,'OROGENIC','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',-65);
    text(0.8,0.27,'SPREADING CENTER ICELAND','HorizontalAlignment','center',...
         'VerticalAlignment','middle','FontSize',10,'FontWeight','b','Rotation',-60);
% Plot data
plot(a3Al,a3F,'Marker','v','MarkerFaceColor','g','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a2Al,a2F,'Marker','o','MarkerFaceColor','b','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
plot(a1Al,a1F,'Marker','s','MarkerFaceColor','r','MarkerEdgeColor','k',...
    'MarkerSize',[6],'LineStyle','none','LineWidth',[1])
    hold off
% Axis titles
text(0,-0.0425,'MgO','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(1,-0.05,'Al_2O_3','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
text(0.5,0.88,'FeO_t_o_t','HorizontalAlignment','center',...
    'VerticalAlignment','middle','FontSize',14,'FontWeight','b');
title('Al_2O_3/FeO_t_o_t/MgO diagram (after Pearce et al., 1977)','FontSize',12,'FontWeight','b')
set(gca,'dataaspectratio',[1 1 1]), axis off;

%% Clear data
clear pearceal4
clear a1sum a1F a1Al
clear a2sum a2F a2Al
clear a3sum a3F a3Al