% Geochemical discrimination of granitoids after Pearce et al. (1984)
%
% Reference: Pearce, J.A., Harris, N.B.W., Tindle, A.G., 1984. Trace element 
% discrimination diagrams for the tectonic interpretation of granitic rocks. 
% Journal of Petrology 25, 956-983.
% 
% Link: doi:10.1093/petrology/25.4.956

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2


    cd(folder_plot)

%% Calculation
n1NbplusY   = n1Nb+n1Y;
n2NbplusY   = n2Nb+n2Y;    
   

n1TaplusYb   = n1Ta+n1Yb;
n2TaplusYb   = n2Ta+n2Yb;    
  


%% Rb vs. Y + Nb diagram
pea1 = figure('Visible','on','Position',[100,100,900,750]);
      set(pea1,'Name','Pearce et al. (1984) discrimination of granitoids - FGAPP v1.0 - 2 datasets')
loglog([2 55 400],[80 300 2000],'k-',...
       [51.5 55],[8 300],'k-',...
       [50 51.5 2000],[1 8 400],'k-','LineWidth',2)
text(8,800,'syn-Collision Granitoid','fontsize',12,'fontweight','b')
text(6,10,'Volcanic Arc Granitoid','fontsize',12,'fontweight','b')
text(100,200,'Within Plate Granitoid','fontsize',12,'fontweight','b')
text(220,15,'Ocean Ridge Granitoid','fontsize',12,'fontweight','b')
    hold all
plot(n2NbplusY,n2Rb,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1NbplusY,n1Rb,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([2 2000 1 2000])
    set(gca,'YTick',[1 10 100 1000],'YTickLabel',[1 10 100 1000],'FontWeight','b','LineWidth',2)
    set(gca,'XTick',[10 100 1000],'XTickLabel',[10 100 1000],'FontWeight','b','LineWidth',2)
    title('Rb vs. Y + Nb classification (after Pearce et al., 1984)','fontsize',12,'fontweight','b')
    xlabel('Y + Nb[ppm]','fontsize',12,'fontweight','b')
    ylabel('Rb [ppm]','fontsize',12,'fontweight','b')
    
%% Rb vs. Yb + Ta diagram
pea2 = figure('Visible','on','Position',[120,120,900,750]);
      set(pea2,'Name','Pearce et al. (1984) discrimination of granitoids - FGAPP v1.0 - 2 datasets')
loglog([0.5 6],[140 200],'k-',...
       [6 6 50],[8 200 2000],'k-',...
       [6 6],[8 1],'k-',...
       [6 200],[8 400],'k-','LineWidth',2)
text(1,800,'syn-Collision Granitoid','fontsize',12,'fontweight','b')
text(0.7,10,'Volcanic Arc Granitoid','fontsize',12,'fontweight','b')
text(10,170,'Within Plate Granitoid','fontsize',12,'fontweight','b')
text(15,5,'Ocean Ridge Granitoid','fontsize',12,'fontweight','b')
    hold all
plot(n2TaplusYb,n2Rb,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1TaplusYb,n1Rb,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([0.5 200 1 2000])
    set(gca,'YTick',[1 10 100 1000],'YTickLabel',[1 10 100 1000],'FontWeight','b','LineWidth',2)
    set(gca,'XTick',[0.1 1 10 100 1000],'XTickLabel',[0.1 1 10 100 1000],'FontWeight','b','LineWidth',2)
    title('Rb vs. Yb + Ta classification (after Pearce et al., 1984)','fontsize',12,'fontweight','b')
    xlabel('Yb + Ta [ppm]','fontsize',12,'fontweight','b')
    ylabel('Rb [ppm]','fontsize',12,'fontweight','b')
    
%% Nb vs. Y diagram
pea3 = figure('Visible','on','Position',[140,140,900,750]);
      set(pea3,'Name','Pearce et al. (1984) discrimination of granitoids - FGAPP v1.0 - 2 datasets')
loglog([40 50],[1 10],'k-',...
       [50 1],[10 2000],'k-',...
       [25 1000],[25 400],'k--',...
       [50 1000],[10 100],'k-','LineWidth',2)
text(2,20,sprintf('syn-Collision Granitoid/\nVolcanic Arc Granitoid'),'fontsize',12,'fontweight','b')
text(20,300,'Within Plate Granitoid','fontsize',12,'fontweight','b')
text(110,5,'Ocean Ridge Granitoid','fontsize',12,'fontweight','b')
    hold all
plot(n2Y,n2Nb,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1Y,n1Nb,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([1 2000 1 2000])
    set(gca,'YTick',[1 10 100 1000],'YTickLabel',[1 10 100 1000],'FontWeight','b','LineWidth',2)
    set(gca,'XTick',[1 10 100 1000],'XTickLabel',[1 10 100 1000],'FontWeight','b','LineWidth',2)
    title('Nb vs. Y classification (after Pearce et al., 1984)','fontsize',12,'fontweight','b')
    xlabel('Y [ppm]','fontsize',12,'fontweight','b')
    ylabel('Nb [ppm]','fontsize',12,'fontweight','b')
    
    %% Ta vs. Yb diagram
pea4 = figure('Visible','on','Position',[160,160,900,750]);
      set(pea4,'Name','Pearce et al. (1984) discrimination of granitoids - FGAPP v1.0 - 2 datasets')
loglog([55 3],[20 2],'k--',...
       [0.1 3],[0.35 2],'k-',...
       [3 5],[2 1],'k-',...
       [3 0.5],[2 20],'k-',...
       [5 5 100],[0.05 1 7],'k-','LineWidth',2)
text(0.4,0.4,sprintf('Volcanic Arc Granitoid'),'fontsize',12,'fontweight','b')
text(0.2,3,sprintf('syn-Collision Granitoid'),'fontsize',12,'fontweight','b')
text(2,10,'Within Plate Granitoid','fontsize',12,'fontweight','b')
text(10,0.4,'Ocean Ridge Granitoid','fontsize',12,'fontweight','b')
    hold all
plot(n2Yb,n2Ta,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1Yb,n1Ta,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
    hold off
    axis ([0.1 100 0.05 100])
    set(gca,'YTick',[0.1 1 10 100 1000],'YTickLabel',[0.1 1 10 100 1000],'FontWeight','b','LineWidth',2)
    set(gca,'XTick',[0.1 1 10 100 1000],'XTickLabel',[0.1 1 10 100 1000],'FontWeight','b','LineWidth',2)
    title('Nb vs. Y classification (after Pearce et al., 1984)','fontsize',12,'fontweight','b')
    xlabel('Yb [ppm]','fontsize',12,'fontweight','b')
    ylabel('Ta [ppm]','fontsize',12,'fontweight','b')

    %% Clear data
clear pea1 pea2 pea3 pea4 
clear 1NbplusY n2NbplusY
clear n1TaplusYb n2TaplusYb