%% Runs the normalization of rare earth elements for 1 dataset. 
% REE are normalized to C1-chondrite, primitive mantle,
% normal-type mid-ocean ridge basalts (NMORB), e-type MORB (EMORB), 
% and oceanic island basalts (OIB).
% 
% Normalizing values are taken from Sun & McDonough (1989)
%
% References: S.-S. Sun and W.F. Mc Donough, 1989. - Chemical and isotopic
% systematics of oceanic basalts: implications for mantle composition and
% processes. In: A.D. Saunders and M.J. Norry (Eds.), 1989. - Magmatism in
% the ocean basins, Geological Society Special Publication No. 42, pp.
% 313-345.

% Runs normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

%% C1-condrite normalization
% C1-condrite normalization values
La = 0.237;  Ce = 0.612;  Pr = 0.095;  Nd = 0.467; % Pm
Sm = 0.153;  Eu = 0.058;  Gd = 0.2055; Tb = 0.0374; 
Dy = 0.2540; Ho = 0.0566; Er = 0.1655; Tm = 0.0255;
Yb = 0.170;  Lu = 0.0254;
% Normalization
C1aLa = r1La./La; C1aCe = r1Ce./Ce; C1aPr = r1Pr./Pr; C1aNd = r1Nd./Nd; % Pm
C1aSm = r1Sm./Sm; C1aEu = r1Eu./Eu; C1aGd = r1Gd./Gd; C1aTb = r1Tb./Tb;
C1aDy = r1Dy./Dy; C1aHo = r1Ho./Ho; C1aEr = r1Er./Er; C1aTm = r1Tm./Tm;
C1aYb = r1Yb./Yb; C1aLu = r1Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); C1aPm = b.*NaN;
% Assemble all REE
C1norm = [C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    C1ree1 = figure('Visible','on','Position',[100,100,900,800]);
    set(C1ree1,'Name','REE plots (C1-chondrite normalized) - FastGAPP v1.0 - 1 dataset')
semilogy(xax,C1norm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / C1-chondrite','fontsize',12,'fontweight','bold')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear C1norm C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu
clear C1ree1

%% Primitive mantle normalization
% Primitive mantle normalization values
La = 0.687;  Ce = 1.775;  Pr = 0.276;  Nd = 1.354; % Pm
Sm = 0.444;  Eu = 0.168;  Gd = 0.596; Tb = 0.108; 
Dy = 0.737; Ho = 0.164; Er = 0.480; Tm = 0.074;
Yb = 0.493;  Lu = 0.074;
% Normalization
PMaLa = r1La./La; PMaCe = r1Ce./Ce; PMaPr = r1Pr./Pr; PMaNd = r1Nd./Nd; % Pm
PMaSm = r1Sm./Sm; PMaEu = r1Eu./Eu; PMaGd = r1Gd./Gd; PMaTb = r1Tb./Tb;
PMaDy = r1Dy./Dy; PMaHo = r1Ho./Ho; PMaEr = r1Er./Er; PMaTm = r1Tm./Tm;
PMaYb = r1Yb./Yb; PMaLu = r1Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); PMaPm = b.*NaN;
% Assemble all REE
PManorm = [PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    PMree1 = figure('Visible','on','Position',[110,110,900,800]);
    set(PMree1,'Name','REE plots (primitive mantle normalized) - FastGAPP v1.0 - 1 dataset')
semilogy(xax,PManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / Primitive mantle','fontsize',12,'fontweight','bold')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear PManorm PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu
clear PMree1

%% N-MORB normalization
% N-MORB normalization values
La = 2.5;  Ce = 7.5;  Pr = 1.32;  Nd = 7.3; % Pm
Sm = 2.63;  Eu = 1.02;  Gd = 3.680; Tb = 0.670; 
Dy = 4.550; Ho = 1.01; Er = 2.97; Tm = 0.456;
Yb = 3.05;  Lu = 0.455;
% Normalization
NMaLa = r1La./La; NMaCe = r1Ce./Ce; NMaPr = r1Pr./Pr; NMaNd = r1Nd./Nd; % Pm
NMaSm = r1Sm./Sm; NMaEu = r1Eu./Eu; NMaGd = r1Gd./Gd; NMaTb = r1Tb./Tb;
NMaDy = r1Dy./Dy; NMaHo = r1Ho./Ho; NMaEr = r1Er./Er; NMaTm = r1Tm./Tm;
NMaYb = r1Yb./Yb; NMaLu = r1Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); NMaPm = b.*NaN;
% Assemble all REE
NManorm = [NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    NMORBree1 = figure('Visible','on','Position',[120,120,900,800]);
    set(NMORBree1,'Name','REE plots (N-type MORB normalized) - FastGAPP v1.0 - 1 dataset')
semilogy(xax,NManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / NMORB','fontsize',12,'fontweight','bold')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear NManorm NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu
clear NMORBree1

%% E-MORB normalization
% E-MORB normalization values
La = 6.3;  Ce = 15.0;  Pr = 2.05;  Nd = 9.00; % Pm
Sm = 2.60;  Eu = 0.91;  Gd = 2.970; Tb = 0.530; 
Dy = 3.550; Ho = 0.790; Er = 2.31; Tm = 0.356;
Yb = 2.37;  Lu = 0.354;
% Normalization
EMORBLa = r1La./La; EMORBCe = r1Ce./Ce; EMORBPr = r1Pr./Pr; EMORBNd = r1Nd./Nd; % Pm
EMORBSm = r1Sm./Sm; EMORBEu = r1Eu./Eu; EMORBGd = r1Gd./Gd; EMORBTb = r1Tb./Tb;
EMORBDy = r1Dy./Dy; EMORBHo = r1Ho./Ho; EMORBEr = r1Er./Er; EMORBTm = r1Tm./Tm;
EMORBYb = r1Yb./Yb; EMORBLu = r1Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); EMORBPm = b.*NaN;
% Assemble all REE
EMORBnorm = [EMORBLa EMORBCe EMORBPr EMORBNd EMORBPm EMORBSm EMORBEu...
             EMORBGd EMORBTb EMORBDy EMORBHo EMORBEr EMORBTm EMORBYb EMORBLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    EMORBree1 = figure('Visible','on','Position',[130,130,900,800]);
    set(EMORBree1,'Name','REE plots (E-type MORB normalized) - FastGAPP v1.0 - 1 dataset')
semilogy(xax,EMORBnorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / EMORB','fontsize',12,'fontweight','bold')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear EMORBnorm EMORBLa EMORBCe EMORBPr EMORBNd EMORBPm EMORBSm EMORBEu EMORBGd EMORBTb EMORBDy EMORBHo EMORBEr EMORBTm EMORBYb EMORBLu
clear EMORBree1

%% OIB normalization
% OIB normalization values
La = 37.0;  Ce = 80.0;  Pr = 9.7;  Nd = 38.5; % Pm
Sm = 10.0;  Eu = 3.0;  Gd = 7.620; Tb = 1.050; 
Dy = 5.600; Ho = 1.06; Er = 2.62; Tm = 0.350;
Yb = 2.16;  Lu = 0.3;
% Normalization
OIBLa = r1La./La; OIBCe = r1Ce./Ce; OIBPr = r1Pr./Pr; OIBNd = r1Nd./Nd; % Pm
OIBSm = r1Sm./Sm; OIBEu = r1Eu./Eu; OIBGd = r1Gd./Gd; OIBTb = r1Tb./Tb;
OIBDy = r1Dy./Dy; OIBHo = r1Ho./Ho; OIBEr = r1Er./Er; OIBTm = r1Tm./Tm;
OIBYb = r1Yb./Yb; OIBLu = r1Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); OIBPm = b.*NaN;
% Assemble all REE
OIBnorm = [OIBLa OIBCe OIBPr OIBNd OIBPm OIBSm OIBEu...
             OIBGd OIBTb OIBDy OIBHo OIBEr OIBTm OIBYb OIBLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    OIBree1 = figure('Visible','on','Position',[140,140,900,800]);
    set(OIBree1,'Name','REE plots (OIB normalized) - FastGAPP v1.0 - 1 dataset')
semilogy(xax,OIBnorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / OIB','fontsize',12,'fontweight','bold')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear OIBnorm OIBLa OIBCe OIBPr OIBNd OIBPm OIBSm OIBEu OIBGd OIBTb OIBDy OIBHo OIBEr OIBTm OIBYb OIBLu
clear OIBree1
