%% Runs the normalization of rare earth elements for 2 datasets. 
% REE are normalized to C1-chondrite, primitive mantle,
% normal-type mid-ocean ridge basalts (NMORB), e-type MORB (EMORB), 
% and oceanic island basalts (OIB).
% 
% Normalizing values are taken from Sun & McDonough (1989)
%
% References: S.-S. Sun and W.F. Mc Donough, 1989. - Chemical and isotopic
% systematics of oceanic basalts: implications for mantle composition and
% processes. In: A.D. Saunders and M.J. Norry (Eds.), 1989. - Magmatism in
% the ocean basins, Geological Society Special Publication No. 42, pp.
% 313-345.

% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    cd(folder_plot)

%% C1-condrite normalization
% C1-condrite normalization values
La = 0.237;  Ce = 0.612;  Pr = 0.095;  Nd = 0.467; % Pm
Sm = 0.153;  Eu = 0.058;  Gd = 0.2055; Tb = 0.0374; 
Dy = 0.2540; Ho = 0.0566; Er = 0.1655; Tm = 0.0255;
Yb = 0.170;  Lu = 0.0254;
% Normalization
C1aLa = r1La./La; C1aCe = r1Ce./Ce; C1aPr = r1Pr./Pr; C1aNd = r1Nd./Nd; % Pm
C1aSm = r1Sm./Sm; C1aEu = r1Eu./Eu; C1aGd = r1Gd./Gd; C1aTb = r1Tb./Tb;
C1aDy = r1Dy./Dy; C1aHo = r1Ho./Ho; C1aEr = r1Er./Er; C1aTm = r1Tm./Tm;
C1aYb = r1Yb./Yb; C1aLu = r1Lu./Lu;
C1bLa = r2La./La; C1bCe = r2Ce./Ce; C1bPr = r2Pr./Pr; C1bNd = r2Nd./Nd; % Pm
C1bSm = r2Sm./Sm; C1bEu = r2Eu./Eu; C1bGd = r2Gd./Gd; C1bTb = r2Tb./Tb;
C1bDy = r2Dy./Dy; C1bHo = r2Ho./Ho; C1bEr = r2Er./Er; C1bTm = r2Tm./Tm;
C1bYb = r2Yb./Yb; C1bLu = r2Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); C1aPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); C1bPm = b.*NaN;
% Assemble all REE
C1anorm = [C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu];
C1bnorm = [C1bLa C1bCe C1bPr C1bNd C1bPm C1bSm C1bEu C1bGd C1bTb C1bDy C1bHo C1bEr C1bTm C1bYb C1bLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    C1ree2 = figure('Visible','on','Position',[100,100,900,800]);
    set(C1ree2,'Name','REE plots (C1-chondrite normalized) - FastGAPP v1.0 - 2 datasets')
semilogy(xax,C1bnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
                hold all
semilogy(xax,C1anorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / C1-chondrite','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear C1anorm C1aLa C1aCe C1aPr C1aNd C1aPm C1aSm C1aEu C1aGd C1aTb C1aDy C1aHo C1aEr C1aTm C1aYb C1aLu
clear C1bnorm C1bLa C1bCe C1bPr C1bNd C1bPm C1bSm C1bEu C1bGd C1bTb C1bDy C1bHo C1bEr C1bTm C1bYb C1bLu
clear C1ree2

%% Primitive mantle normalization
% Primitive mantle normalization values
La = 0.687;  Ce = 1.775;  Pr = 0.276;  Nd = 1.354; % Pm
Sm = 0.444;  Eu = 0.168;  Gd = 0.596; Tb = 0.108; 
Dy = 0.737; Ho = 0.164; Er = 0.480; Tm = 0.074;
Yb = 0.493;  Lu = 0.074;
% Normalization
PMaLa = r1La./La; PMaCe = r1Ce./Ce; PMaPr = r1Pr./Pr; PMaNd = r1Nd./Nd; % Pm
PMaSm = r1Sm./Sm; PMaEu = r1Eu./Eu; PMaGd = r1Gd./Gd; PMaTb = r1Tb./Tb;
PMaDy = r1Dy./Dy; PMaHo = r1Ho./Ho; PMaEr = r1Er./Er; PMaTm = r1Tm./Tm;
PMaYb = r1Yb./Yb; PMaLu = r1Lu./Lu;
PMbLa = r2La./La; PMbCe = r2Ce./Ce; PMbPr = r2Pr./Pr; PMbNd = r2Nd./Nd; % Pm
PMbSm = r2Sm./Sm; PMbEu = r2Eu./Eu; PMbGd = r2Gd./Gd; PMbTb = r2Tb./Tb;
PMbDy = r2Dy./Dy; PMbHo = r2Ho./Ho; PMbEr = r2Er./Er; PMbTm = r2Tm./Tm;
PMbYb = r2Yb./Yb; PMbLu = r2Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); PMaPm = b.*NaN; 
[h b] = size(r2La); b = ones(h,1); PMbPm = b.*NaN;
% Assemble all REE
PManorm = [PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu];
PMbnorm = [PMbLa PMbCe PMbPr PMbNd PMbPm PMbSm PMbEu PMbGd PMbTb PMbDy PMbHo PMbEr PMbTm PMbYb PMbLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    PMree2 = figure('Visible','on','Position',[110,110,900,800]);
    set(PMree2,'Name','REE plots (primitive mantle normalized) - FastGAPP v1.0 - 2 datasets')
semilogy(xax,PMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b') 
                hold all
semilogy(xax,PManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 1 2000])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.1 1 10 100 1000],...
          'YTickLabel',[0.1 1 10 100 1000],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / Primitive mantle','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear PManorm PMaLa PMaCe PMaPr PMaNd PMaPm PMaSm PMaEu PMaGd PMaTb PMaDy PMaHo PMaEr PMaTm PMaYb PMaLu
clear PMbnorm PMbLa PMbCe PMbPr PMbNd PMbPm PMbSm PMbEu PMbGd PMbTb PMbDy PMbHo PMbEr PMbTm PMbYb PMbLu
clear PMree2

%% N-MORB normalization
% N-MORB normalization values
La = 2.5;  Ce = 7.5;  Pr = 1.32;  Nd = 7.3; % Pm
Sm = 2.63;  Eu = 1.02;  Gd = 3.680; Tb = 0.670; 
Dy = 4.550; Ho = 1.01; Er = 2.97; Tm = 0.456;
Yb = 3.05;  Lu = 0.455;
% Normalization
NMaLa = r1La./La; NMaCe = r1Ce./Ce; NMaPr = r1Pr./Pr; NMaNd = r1Nd./Nd; % Pm
NMaSm = r1Sm./Sm; NMaEu = r1Eu./Eu; NMaGd = r1Gd./Gd; NMaTb = r1Tb./Tb;
NMaDy = r1Dy./Dy; NMaHo = r1Ho./Ho; NMaEr = r1Er./Er; NMaTm = r1Tm./Tm;
NMaYb = r1Yb./Yb; NMaLu = r1Lu./Lu;
NMbLa = r2La./La; NMbCe = r2Ce./Ce; NMbPr = r2Pr./Pr; NMbNd = r2Nd./Nd; % Pm
NMbSm = r2Sm./Sm; NMbEu = r2Eu./Eu; NMbGd = r2Gd./Gd; NMbTb = r2Tb./Tb;
NMbDy = r2Dy./Dy; NMbHo = r2Ho./Ho; NMbEr = r2Er./Er; NMbTm = r2Tm./Tm;
NMbYb = r2Yb./Yb; NMbLu = r2Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); NMaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); NMbPm = b.*NaN;
% Assemble all REE
NManorm = [NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu];
NMbnorm = [NMbLa NMbCe NMbPr NMbNd NMbPm NMbSm NMbEu NMbGd NMbTb NMbDy NMbHo NMbEr NMbTm NMbYb NMbLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    NMORBree2 = figure('Visible','on','Position',[120,120,900,800]);
    set(NMORBree2,'Name','REE plots (N-type MORB normalized) - FastGAPP v1.0 - 2 datasets')
semilogy(xax,NMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
                hold all
semilogy(xax,NManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / NMORB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear NManorm NMaLa NMaCe NMaPr NMaNd NMaPm NMaSm NMaEu NMaGd NMaTb NMaDy NMaHo NMaEr NMaTm NMaYb NMaLu
clear NMbnorm NMbLa NMbCe NMbPr NMbNd NMbPm NMbSm NMbEu NMbGd NMbTb NMbDy NMbHo NMbEr NMbTm NMbYb NMbLu
clear NMORBree2

%% E-MORB normalization
% E-MORB normalization values
La = 6.3;  Ce = 15.0;  Pr = 2.05;  Nd = 9.00; % Pm
Sm = 2.60;  Eu = 0.91;  Gd = 2.970; Tb = 0.530; 
Dy = 3.550; Ho = 0.790; Er = 2.31; Tm = 0.356;
Yb = 2.37;  Lu = 0.354;
% Normalization
EMaLa = r1La./La; EMaCe = r1Ce./Ce; EMaPr = r1Pr./Pr; EMaNd = r1Nd./Nd; % Pm
EMaSm = r1Sm./Sm; EMaEu = r1Eu./Eu; EMaGd = r1Gd./Gd; EMaTb = r1Tb./Tb;
EMaDy = r1Dy./Dy; EMaHo = r1Ho./Ho; EMaEr = r1Er./Er; EMaTm = r1Tm./Tm;
EMaYb = r1Yb./Yb; EMaLu = r1Lu./Lu;
EMbLa = r2La./La; EMbCe = r2Ce./Ce; EMbPr = r2Pr./Pr; EMbNd = r2Nd./Nd; % Pm
EMbSm = r2Sm./Sm; EMbEu = r2Eu./Eu; EMbGd = r2Gd./Gd; EMbTb = r2Tb./Tb;
EMbDy = r2Dy./Dy; EMbHo = r2Ho./Ho; EMbEr = r2Er./Er; EMbTm = r2Tm./Tm;
EMbYb = r2Yb./Yb; EMbLu = r2Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); EMaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); EMbPm = b.*NaN;
% Assemble all REE
EManorm = [EMaLa EMaCe EMaPr EMaNd EMaPm EMaSm EMaEu EMaGd EMaTb EMaDy EMaHo EMaEr EMaTm EMaYb EMaLu];
EMbnorm = [EMbLa EMbCe EMbPr EMbNd EMbPm EMbSm EMbEu EMbGd EMbTb EMbDy EMbHo EMbEr EMbTm EMbYb EMbLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    EMORBree2 = figure('Visible','on','Position',[130,130,900,800]);
    set(EMORBree2,'Name','REE plots (E-type MORB normalized) - FastGAPP v1.0 - 2 datasets')
semilogy(xax,EMbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
                hold all
semilogy(xax,EManorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')               
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / EMORB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear EManorm EMaLa EMaCe EMaPr EMaNd EMaPm EMaSm EMaEu EMaGd EMaTb EMaDy EMaHo EMaEr EMaTm EMaYb EMaLu
clear EMbnorm EMbLa EMbCe EMbPr EMbNd EMbPm EMbSm EMbEu EMbGd EMbTb EMbDy EMbHo EMbEr EMbTm EMbYb EMbLu
clear EMORBree2

%% OIB normalization
% OIB normalization values
La = 37.0;  Ce = 80.0;  Pr = 9.7;  Nd = 38.5; % Pm
Sm = 10.0;  Eu = 3.0;  Gd = 7.620; Tb = 1.050; 
Dy = 5.600; Ho = 1.06; Er = 2.62; Tm = 0.350;
Yb = 2.16;  Lu = 0.3;
% Normalization
OIBaLa = r1La./La; OIBaCe = r1Ce./Ce; OIBaPr = r1Pr./Pr; OIBaNd = r1Nd./Nd; % Pm
OIBaSm = r1Sm./Sm; OIBaEu = r1Eu./Eu; OIBaGd = r1Gd./Gd; OIBaTb = r1Tb./Tb;
OIBaDy = r1Dy./Dy; OIBaHo = r1Ho./Ho; OIBaEr = r1Er./Er; OIBaTm = r1Tm./Tm;
OIBaYb = r1Yb./Yb; OIBaLu = r1Lu./Lu;
OIBbLa = r2La./La; OIBbCe = r2Ce./Ce; OIBbPr = r2Pr./Pr; OIBbNd = r2Nd./Nd; % Pm
OIBbSm = r2Sm./Sm; OIBbEu = r2Eu./Eu; OIBbGd = r2Gd./Gd; OIBbTb = r2Tb./Tb;
OIBbDy = r2Dy./Dy; OIBbHo = r2Ho./Ho; OIBbEr = r2Er./Er; OIBbTm = r2Tm./Tm;
OIBbYb = r2Yb./Yb; OIBbLu = r2Lu./Lu;
% Create Pm coloumn
[h b] = size(r1La); b = ones(h,1); OIBaPm = b.*NaN;
[h b] = size(r2La); b = ones(h,1); OIBbPm = b.*NaN;
% Assemble all REE
OIBanorm = [OIBaLa OIBaCe OIBaPr OIBaNd OIBaPm OIBaSm OIBaEu OIBaGd OIBaTb OIBaDy OIBaHo OIBaEr OIBaTm OIBaYb OIBaLu];
OIBbnorm = [OIBbLa OIBbCe OIBbPr OIBbNd OIBbPm OIBbSm OIBbEu OIBbGd OIBbTb OIBbDy OIBbHo OIBbEr OIBbTm OIBbYb OIBbLu];
xax    = [1:15];
reetext = {'La' 'Ce' 'Pr' 'Nd' 'Pm' 'Sm' 'Eu' 'Gd' 'Tb' 'Dy' 'Ho' 'Er' 'Tm' 'Yb' 'Lu'};
% Create the figure
    OIBree2 = figure('Visible','on','Position',[140,140,900,800]);
    set(OIBree2,'Name','REE plots (OIB normalized) - FastGAPP v1.0 - 2 datasets')
semilogy(xax,OIBbnorm,'LineStyle','-','Color','b','LineWidth',[2],'Marker','o',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','b')
                hold all
semilogy(xax,OIBanorm,'LineStyle','-','Color','r','LineWidth',[2],'Marker','s',...
                    'MarkerSize',[6],'MarkerEdgeColor','k',...
                    'MarkerFaceColor','r')
                hold off
          axis ([0.75 15.25 0.01 200])
          set(gca,'LineWidth',2,'fontsize',8,'XTick',[1 2 3 4 5 6 7 8 9 10 11 12 13 14 15],...
          'XTickLabel',reetext,'FontWeight','bold','FontName','Arial');
          set(gca,'LineWidth',2,'fontsize',8,'YTick',[0.01 0.1 1 10 100],...
          'YTickLabel',[0.01 0.1 1 10 100],'FontWeight','bold','FontName','Arial');
          title('REE plots (Normalizing values after Sun & McDonough, 1989)','FontWeight','b','FontSize',12)
          ylabel('Sample / OIB','fontsize',12,'fontweight','b')
      
% Clear data
clear La Ce Pr Nd Sm Eu Gd Tb Dy Ho Er Tm Yb Lu
clear h b xax reetext
clear OIBanorm OIBaLa OIBaCe OIBaPr OIBaNd OIBaPm OIBaSm OIBaEu OIBaGd OIBaTb OIBaDy OIBaHo OIBaEr OIBaTm OIBaYb OIBaLu
clear OIBbnorm OIBbLa OIBbCe OIBbPr OIBbNd OIBbPm OIBbSm OIBbEu OIBbGd OIBbTb OIBbDy OIBbHo OIBbEr OIBbTm OIBbYb OIBbLu
clear OIBree2
