% Generates the K2O versus silica classification of subduction zone
% volcanics after Peccerillo and Taylor (1976).
%
% Reference: Peccerillo, A., Taylor, S.R., 1976. Geochemistry of eocene 
% calc-alkaline volcanic rocks from the Kastamonu area, Northern Turkey. 
% Contributions to Mineralogy and Petrology 58, 63-81.
%
% Link: http://dx.doi.org/10.1007/bf00384745

%% Runs normalization
    cd(folder_norm)
    normalization1
    normalization2
    cd(folder_plot)

    %% Subduction classification
% K2O vs. silica diagram
subd1 = figure('Visible','on','Position',[200,100,900,800]);
    movegui(subd1,'center')
    set(subd1,'Name','TAS diagram - FGAPP v1.0 - 2 datasets')
% Generate the division line
plot([48 53 57 63],[1.6 2.5 3.3 4],'k-',[53 53],[0 4],'k-',[57 57],[0 4],'k-',...
     [53 57 63 68],[1.6 1.9 2.4 2.8],'k-',[63 63],[0 4],'k-',[68 68],[0 4],'k-',...
     [48 57 63 78],[0.3 0.75 0.95 1.6],'k-','LineWidth',2)
 hold all
    text(49,0.2,sprintf('K-poor \nTholeiite'),'fontsize',12,'fontweight','b')
    text(53.6,0.25,sprintf('K-poor \nBasaltic\nAndesite'),'fontsize',12,'fontweight','b')
    text(58.5,0.35,sprintf('K-poor \nAndesite'),'fontsize',12,'fontweight','b')
    text(64.5,0.45,sprintf('K-poor \nDacite'),'fontsize',12,'fontweight','b')
    text(71,0.55,sprintf('K-poor \nRhyolite'),'fontsize',12,'fontweight','b')
    text(49,1,'Basalt','fontsize',12,'fontweight','b')
    text(53.6,1.2,sprintf('Basaltic\nAndesite'),'fontsize',12,'fontweight','b')
    text(58.5,1.4,sprintf('Andesite'),'fontsize',12,'fontweight','b')
    text(64.5,1.6,sprintf('Dacite'),'fontsize',12,'fontweight','b')
    text(71,2,sprintf('Rhyolite'),'fontsize',12,'fontweight','b')
    text(53.6,2.25,sprintf('K-rich \nBasaltic\nAndesite'),'fontsize',12,'fontweight','b')
    text(58.5,2.7,sprintf('K-rich \nAndesite'),'fontsize',12,'fontweight','b')
    text(64.6,3,sprintf('Latite'),'fontsize',12,'fontweight','b')
    text(49,3,'Absarokite','fontsize',12,'fontweight','b')
    text(53.2,3.4,sprintf('Shoshonite'),'fontsize',12,'fontweight','b')
    text(58,3.8,sprintf('Banakite'),'fontsize',12,'fontweight','b')
plot(n2SiO2,n2K2O,'o','MarkerEdgeColor','k',...
                    'MarkerFaceColor','b',...
                    'MarkerSize',6)
plot(n1SiO2,n1K2O,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([48 78 0 4])
box on
set(gca,'XTick',48:2:78,'FontWeight','bold','YTick',0:0.5:4,'LineWidth',2)
title('Classification of subduction related volcanics (after Peccerillo & Taylor, 1976)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('K_2O [wt.%]','fontsize',12,'fontweight','b')

%% Clear data
clear subd1