% Generates the TAS diagram for four datasets with classification fields 
% (Le Bas et al., 1986) and the two division line for discrimation between 
% alkaline and sub-alkaline suites (MacDonald, 1968, Irvine & Baragar) and
% the classification of plutonic rocks after Middlemost
% 
% References:
%
% M. J. Le Bas, R. W. Le Maitre, A. Streckeisen, B. Zanettin,
% and IUGS Subcommission on the Systematics of Igneous Rocks (1986).
% A  chemical classification  of  volcanic  rocks  based  on  the  
% total  alkalisilica  diagram.  - Journal of Petrology 27, 745750.
% 
% G. A. MacDonald (1968). Composition and origin of Hawaiian lavas. - 
% Geological Society of America Memoirs 116, 477-522.
%
% Irvine, T.N., Baragar, W.R.A., 1971. A Guide to the Chemical 
% Classification of the Common Volcanic Rocks. Canadian Journal 
% of Earth Sciences 8, 523-548.
%
% Middlemost, E.A.K., 1994. Naming materials in the magma/igneous rock system. 
% Earth-Science Reviews 37, 215-224.

%% Runs normalization
    cd(folder_norm)
    normalization1
    cd(folder_plot)

%% Calculation
    n1Alk = n1Na2O+n1K2O;

    %% TAS division line - MacDonald
% TAS diagram
tas1 = figure('Visible','on','Position',[100,100,1280,800]);
    set(tas1,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([39 66.5],[0 10],'k--','LineWidth',2)
    text(54.5,6.5,'alkaline','fontsize',12,'fontweight','b','Rotation',35.6)
    text(55.2,5.2,'subalkaline','fontsize',12,'fontweight','b','Rotation',35.6)
   hold all
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([35 80 0 16])
set(gca,'XTick',35:5:80,'FontWeight','bold','YTick',0:2:16,'LineWidth',2)
title('TAS diagram (after MacDonald, 1968)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% TAS division line - Irvine & Baragar
% TAS diagram
tas2 = figure('Visible','on','Position',[110,110,1280,800]);
    set(tas2,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([39 41 43 45 47 49 51 53 55 57 59 61 63],...
     [0 1.025 1.97 2.825 3.6 4.35 5.07 5.75 6.4 7 7.59 8.18 8.75],'k--','LineWidth',2)
    text(54.5,6.8,'alkaline','fontsize',12,'fontweight','b','Rotation',31.8)
    text(55,5.8,'subalkaline','fontsize',12,'fontweight','b','Rotation',31.8)
   hold all
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([35 80 0 16])
set(gca,'XTick',35:5:80,'FontWeight','bold','YTick',0:2:16,'LineWidth',2)
title('TAS diagram (after Irvine & Baragar, 1968)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% TAS fields - Le Bas et al.
% TAS diagram
tas3 = figure('Visible','on','Position',[120,120,1280,800]);
    set(tas3,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([41 41 41 45 48.4 52.5],[0 3 7 9.4 11.5 14],'k-',[41 45],[3 3],'k-',...
     [45 45 45 49.4 53 57.6 64],[0 3 5 7.3 9.3 11.7 15],'k-',...
     [45 52 57 63 69],[5 5 5.9 7 8],'k-',[52 52 49.4 45],[0 5 7.3 9.4],'k-',...
     [57 57 53 48.4],[0 5.9 9.3 11.5],'k-',[63 63 57.6 50.3],[0 7 11.7 15],'k-',...
     [77 69 69],[0 8 15],'k-','LineWidth',2)
    text(73,7,'Rhyolite','fontsize',10,'fontweight','b')
    text(66,6,'Dacite','fontsize',10,'fontweight','b')
    text(58.5,5,'Andesite','fontsize',10,'fontweight','b')
    text(53.3,4,sprintf('Basaltic\nAndesite'),'fontsize',10,'fontweight','b')
    text(47.5,2.5,'Basalt','fontsize',10,'fontweight','b')
    text(42.2,2.3,sprintf('Picro-\nbasalt'),'fontsize',10,'fontweight','b')
    text(48,5.8,sprintf('Trachy-\nbasalt'),'fontsize',10,'fontweight','b')
    text(37.5,7,'Foidite','fontsize',10,'fontweight','b')
    text(56,13.5,sprintf('Phonolite'),'fontsize',10,'fontweight','b')
    text(52,11.5,sprintf('Tephri-\nphonolite'),'fontsize',10,'fontweight','b')
    text(48,9.5,sprintf('Phono-\ntephrite'),'fontsize',10,'fontweight','b')
    text(43,6.5,sprintf('Basanite/\nTephrite'),'fontsize',10,'fontweight','b')
    text(61,10.5,sprintf('Trachyte/\nTrachydacite'),'fontsize',10,'fontweight','b')
    text(56,8.5,sprintf('Basaltic\nTrachyandesite'),'fontsize',10,'fontweight','b')
    text(52,7,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
   hold all
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([35 80 0 16])
set(gca,'XTick',35:5:80,'FontWeight','bold','YTick',0:2:16,'LineWidth',2)
title('TAS diagram (after Le Bas et al., 1986)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% TAS fields and division line - Le Bas et al. & MacDonald
% TAS diagram
tas4 = figure('Visible','on','Position',[130,130,1280,800]);
    set(tas4,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([41 41 41 45 48.4 52.5],[0 3 7 9.4 11.5 14],'k-',[41 45],[3 3],'k-',...
     [45 45 45 49.4 53 57.6 64],[0 3 5 7.3 9.3 11.7 15],'k-',...
     [45 52 57 63 69],[5 5 5.9 7 8],'k-',[52 52 49.4 45],[0 5 7.3 9.4],'k-',...
     [57 57 53 48.4],[0 5.9 9.3 11.5],'k-',[63 63 57.6 50.3],[0 7 11.7 15],'k-',...
     [77 69 69],[0 8 15],'k-','LineWidth',2)
 hold all
    plot([39 66.5],[0 10],'k--','LineWidth',2)
    text(54.5,6.5,'alkaline','fontsize',12,'fontweight','b','Rotation',35.6,'Margin',1,'BackgroundColor','w')
    text(55.2,5.2,'subalkaline','fontsize',12,'fontweight','b','Rotation',35.6,'Margin',1,'BackgroundColor','w')
    text(73,7,'Rhyolite','fontsize',10,'fontweight','b')
    text(66,6,'Dacite','fontsize',10,'fontweight','b')
    text(58.5,5,'Andesite','fontsize',10,'fontweight','b')
    text(53.3,4,sprintf('Basaltic\nAndesite'),'fontsize',10,'fontweight','b')
    text(47.5,2.5,'Basalt','fontsize',10,'fontweight','b')
    text(42.2,2.3,sprintf('Picro-\nbasalt'),'fontsize',10,'fontweight','b')
    text(48,5.8,sprintf('Trachy-\nbasalt'),'fontsize',10,'fontweight' ,'b')
    text(37.5,7,'Foidite','fontsize',10,'fontweight','b')
    text(56,13.5,sprintf('Phonolite'),'fontsize',10,'fontweight','b')
    text(52,11.5,sprintf('Tephri-\nphonolite'),'fontsize',10,'fontweight','b')
    text(48,9.5,sprintf('Phono-\ntephrite'),'fontsize',10,'fontweight','b')
    text(43,6.5,sprintf('Basanite/\nTephrite'),'fontsize',10,'fontweight','b')
    text(61,10.5,sprintf('Trachyte/\nTrachydacite'),'fontsize',10,'fontweight','b')
    text(56,8.5,sprintf('Basaltic\nTrachyandesite'),'fontsize',10,'fontweight','b')
    text(52,7,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([35 80 0 16])
set(gca,'XTick',35:5:80,'FontWeight','bold','YTick',0:2:16,'LineWidth',2)
title('TAS diagram (after MacDonald, 1968, Le Bas et al., 1986)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% TAS fields and division line - Le Bas et al. & Irvine & Baragar
% TAS diagram
tas5 = figure('Visible','on','Position',[140,140,1280,800]);
    set(tas5,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([41 41 41 45 48.4 52.5],[0 3 7 9.4 11.5 14],'k-',[41 45],[3 3],'k-',...
     [45 45 45 49.4 53 57.6 64],[0 3 5 7.3 9.3 11.7 15],'k-',...
     [45 52 57 63 69],[5 5 5.9 7 8],'k-',[52 52 49.4 45],[0 5 7.3 9.4],'k-',...
     [57 57 53 48.4],[0 5.9 9.3 11.5],'k-',[63 63 57.6 50.3],[0 7 11.7 15],'k-',...
     [77 69 69],[0 8 15],'k-','LineWidth',2)
    hold all
 plot([39 41 43 45 47 49 51 53 55 57 59 61 63],...
     [0 1.025 1.97 2.825 3.6 4.35 5.07 5.75 6.4 7 7.59 8.18 8.75],'k--','LineWidth',2)
    text(54.5,6.8,'alkaline','fontsize',12,'fontweight','b','Rotation',31.8,'Margin',1,'BackgroundColor','w')
    text(55,5.8,'subalkaline','fontsize',12,'fontweight','b','Rotation',31.8,'Margin',1,'BackgroundColor','w')
    text(73,7,'Rhyolite','fontsize',10,'fontweight','b')
    text(66,6,'Dacite','fontsize',10,'fontweight','b')
    text(58.5,5,'Andesite','fontsize',10,'fontweight','b')
    text(53.3,4,sprintf('Basaltic\nAndesite'),'fontsize',10,'fontweight','b')
    text(47.5,2.5,'Basalt','fontsize',10,'fontweight','b')
    text(42.2,2.3,sprintf('Picro-\nbasalt'),'fontsize',10,'fontweight','b')
    text(48,5.8,sprintf('Trachy-\nbasalt'),'fontsize',10,'fontweight' ,'b')
    text(37.5,7,'Foidite','fontsize',10,'fontweight','b')
    text(56,13.5,sprintf('Phonolite'),'fontsize',10,'fontweight','b')
    text(52,11.5,sprintf('Tephri-\nphonolite'),'fontsize',10,'fontweight','b')
    text(48,9.5,sprintf('Phono-\ntephrite'),'fontsize',10,'fontweight','b')
    text(43,6.5,sprintf('Basanite/\nTephrite'),'fontsize',10,'fontweight','b')
    text(61,10.5,sprintf('Trachyte/\nTrachydacite'),'fontsize',10,'fontweight','b')
    text(56,8.5,sprintf('Basaltic\nTrachyandesite'),'fontsize',10,'fontweight','b')
    text(52,7,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([35 80 0 16])
set(gca,'XTick',35:5:80,'FontWeight','bold','YTick',0:2:16,'LineWidth',2)
title('TAS diagram (after Irvine & Baragar, 1971, Le Bas et al., 1986)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% Volcanic TAS fields - Middlemost (1994)
% TAS diagram
tas6 = figure('Visible','on','Position',[150,150,1280,800]);
    set(tas6,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([41 41 41 45 48.4 52.5 52.5 37 35 37 45],[0 3 7 9.4 11.5 14 18 14 9 3 3],'k-',...
     [45 45 45 49.4 53 57.6 61 63 57 52.5],[0 3 5 7.3 9.3 11.7 13.5 16.2 18 18],'k-',...
     [45 52 57 63 69 77.3 87.5 85.9 71.8 69],[5 5 5.9 7 8 0 4.7 6.8 13.5 8],'k-',...
     [52 52 49.4 45],[0 5 7.3 9.4],'k-',[61 71.8 63],[8.6 13.5 16.2],'k-',[45 52],[2 5],'k-',...
     [57 57 53 48.4],[0 5.9 9.3 11.5],'k-',[63 63 61 57.6 52.5],[0 7 8.6 11.7 14],'k-','LineWidth',2)
    hold all
    text(48,18.3,sprintf('Sodalinite / Nephelinolith / Leucitolith'),'fontsize',10,'fontweight','b')
    text(73,7,'Rhyolite','fontsize',10,'fontweight','b')
    text(82,1.5,'Silexite','fontsize',10,'fontweight','b')
    text(65,5.5,'Dacite','fontsize',10,'fontweight','b')
    text(58.5,5,'Andesite','fontsize',10,'fontweight','b')
    text(53,4,sprintf('Basaltic\nAndesite'),'fontsize',10,'fontweight','b')
    text(46,4.2,sprintf('Alkalic\nBasalt'),'fontsize',10,'fontweight','b')
    text(47,2,sprintf('Subalkalic\nBasalt'),'fontsize',10,'fontweight','b')
    text(42.1,2.3,sprintf('Picro-\nbasalt'),'fontsize',10,'fontweight','b')
    text(47.8,5.5,sprintf('Trachy-\nbasalt'),'fontsize',10,'fontweight' ,'b')
    text(39,9.5,'Foidite','fontsize',10,'fontweight','b')
    text(55,15,sprintf('Phonolite'),'fontsize',10,'fontweight','b')
    text(52,11.5,sprintf('Tephri-\nphonolite'),'fontsize',10,'fontweight','b')
    text(48,9.5,sprintf('Phono-\ntephrite'),'fontsize',10,'fontweight','b')
    text(42.5,6.5,sprintf('Tephrite'),'fontsize',10,'fontweight','b')
    text(62,12,sprintf('Trachyte'),'fontsize',10,'fontweight','b')
    text(63,8.4,sprintf('Trachydacite'),'fontsize',10,'fontweight','b')
    text(56,8.5,sprintf('Basaltic\nTrachy-\nandesite'),'fontsize',10,'fontweight','b')
    text(52,7,sprintf('Trachy-\nandesite'),'fontsize',10,'fontweight','b')
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([30 90 0 19])
set(gca,'XTick',30:5:90,'FontWeight','bold','YTick',0:2:19,'LineWidth',2)
title('TAS diagram for volcanic rocks (after Middlemost, 1994)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

    %% Plutonic TAS fields - Middlemost (1994)
% TAS diagram
tas7 = figure('Visible','on','Position',[160,160,1280,800]);
    set(tas7,'Name','TAS diagram - FGAPP v1.0 - 1 dataset')
% Generate the division line
plot([41 41 41 45 48.4 52.5 52.5 37 35 37 45],[0 3 7 9.4 11.5 14 18 14 9 3 3],'k-',...
     [45 45 45 49.4 53 57.6 61 63 57 52.5],[0 3 5 7.3 9.3 11.7 13.5 16.2 18 18],'k-',...
     [45 52 57 63 69 77.3 87.5 85.9 71.8 69],[5 5 5.9 7 8 0 4.7 6.8 13.5 8],'k-',...
     [52 52 49.4 45],[0 5 7.3 9.4],'k-',[61 71.8 63],[8.6 13.5 16.2],'k-',[45 52],[2 5],'k-',...
     [57 57 53 48.4],[0 5.9 9.3 11.5],'k-',[63 63 61 57.6 52.5],[0 7 8.6 11.7 14],'k-','LineWidth',2)
    hold all
    text(49,18.3,sprintf('Twanite / Urtite / Italite'),'fontsize',10,'fontweight','b')
    text(73,7,'Granite','fontsize',10,'fontweight','b')
    text(82,1.5,'Quartzolite','fontsize',10,'fontweight','b')
    text(65,5.5,'Granodiorite','fontsize',10,'fontweight','b')
    text(58.5,5,'Diorite','fontsize',10,'fontweight','b')
    text(53,4,sprintf('Gabbroic\nDiorite'),'fontsize',10,'fontweight','b')
    text(46,4.2,sprintf('Alkalic\nGabbro'),'fontsize',10,'fontweight','b')
    text(47,2,sprintf('Subalkalic\nGabbro'),'fontsize',10,'fontweight','b')
    text(42.1,2.3,sprintf('Peridot-\ngabbro'),'fontsize',10,'fontweight','b')
    text(47.7,5.7,sprintf('Monzo-\ngabbro'),'fontsize',10,'fontweight' ,'b')
    text(39,9.5,'Foidolite','fontsize',10,'fontweight','b')
    text(53,15,sprintf('Foid Syenite'),'fontsize',10,'fontweight','b')
    text(51,11.5,sprintf('Foid-\nMonzosyenite'),'fontsize',10,'fontweight','b')
    text(47,9.5,sprintf('Foid-\nMonzodiorite'),'fontsize',10,'fontweight','b')
    text(42.5,6.5,sprintf('Foid Gabbro'),'fontsize',10,'fontweight','b')
    text(62,12,sprintf('Syenite'),'fontsize',10,'fontweight','b')
    text(63.25,8.5,sprintf('Quartz\nMonzonite'),'fontsize',10,'fontweight','b')
    text(56,8.5,sprintf('Monzonite'),'fontsize',10,'fontweight','b')
    text(52,7,sprintf('Monzo-\ndiorite'),'fontsize',10,'fontweight','b')
plot(n1SiO2,n1Alk,'s','MarkerEdgeColor','k',...
                    'MarkerFaceColor','r',...
                    'MarkerSize',6)
   hold off
axis ([30 90 0 19])
set(gca,'XTick',30:5:90,'FontWeight','bold','YTick',0:2:19,'LineWidth',2)
title('TAS diagram for plutonic rocks (after Middlemost, 1994)','fontsize',12,'fontweight','b')
xlabel('SiO_2 [wt.%]','fontsize',12,'fontweight','b')
ylabel('Na_2O + K_2O [wt.%]','fontsize',12,'fontweight','b')

%% Clear data
clear tas1 tas2 tas3 tas4 tas5 tas6 tas7 n1Alk